getPlatformFileSystem function
FileSystem
getPlatformFileSystem()
Returns a MemoryFileSystem for platforms where local disk is unsupported (web).
Implementation
FileSystem getPlatformFileSystem() => _fs;
Returns a MemoryFileSystem for platforms where local disk is unsupported (web).
FileSystem getPlatformFileSystem() => _fs;