IsolateSink class

A TracerSink that spawns a background Isolate to perform zero-jank JSON serialization and disk writes.

Implemented types

Constructors

IsolateSink(String path, int baseEpochUs)
Creates a new IsolateSink writing to path.

Properties

baseEpochUs int
The base epoch timestamp in microseconds for the trace.
final
hashCode int
The hash code for this object.
no setterinherited
path String
The path where the trace file will be written.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(List<int> buffer, List<String> newStrings) → void
Send a buffer of event data and list of newly registered strings to the sink.
override
close() Future<void>
Close the sink and ensure all pending trace data is flushed to the target.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited