Tracer class

A high-performance, low-overhead event tracer.

Constructors

Tracer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

activeCategories Set<TraceCategory>
Active configuration of trace categories to record.
getter/setter pair
isEnabled bool
Whether the tracer is currently enabled and recording events.
getter/setter pair

Static Methods

initialize() Future<void>
Initialize the tracer subsystem.
record(int stringId, int phase, TraceCategory category, {Map<String, String>? metadata}) → void
Record a trace event to the buffer.
registerString(String name) int
Register a string literal and return its static ID.
start(String traceFilePath, {FileSystem? fs}) Future<void>
Start a recording session.
stop() Future<void>
Flush any remaining events and shut down the recording session.