WebTerminalBackend class

A terminal backend implementation for web environments.

Implemented types

Constructors

WebTerminalBackend()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isWindows → bool
Whether the host platform is Windows.
no setteroverride
onWrite ↔ void Function(String)?
Callback to capture ANSI escape sequence output.
getter/setter pair
rawInput → Stream<List<int>>
Stream of raw input bytes from the terminal.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Point<int>
Retrieves the current terminal size.
no setteroverride

Methods

disableRawMode() → void
Restores terminal configuration.
override
dispose() → void
Cleans up resources.
override
enableRawMode() → void
Configures raw mode.
override
injectInput(List<int> bytes) → void
Allows the web container or terminal emulator to inject keystroke bytes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateSize(Point<int> newSize) → void
Allows the web container or terminal emulator to notify us of resizing.
watchSize() → Stream<Point<int>>
Watches terminal size changes.
override
write(String data) → void
Writes output data back to the terminal.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited