FocusInEvent class

Event fired when terminal receives focus.

Inheritance

Constructors

FocusInEvent()
Creates a FocusInEvent.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
key String
The key string representation.
no setterinherited
modifiers Set<Modifier>
Active modifiers.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override