InputEvent class abstract

Base class for all input events.

Implementers

Constructors

InputEvent()
Creates an InputEvent.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
The key string representation.
no setter
modifiers Set<Modifier>
Active modifiers.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited