KeyType enum

Types of keys that can be pressed.

Inheritance
Available extensions

Values

character → const KeyType

Regular character.

backspace → const KeyType

Backspace key.

enter → const KeyType

Enter key.

escape → const KeyType

Escape key.

tab → const KeyType

Tab key.

up → const KeyType

Up arrow key.

down → const KeyType

Down arrow key.

left → const KeyType

Left arrow key.

Right arrow key.

home → const KeyType

Home key.

end → const KeyType

End key.

pageUp → const KeyType

Page Up key.

pageDown → const KeyType

Page Down key.

delete → const KeyType

Delete key.

insert → const KeyType

Insert key.

f1 → const KeyType

F1 key.

f2 → const KeyType

F2 key.

f3 → const KeyType

F3 key.

f4 → const KeyType

F4 key.

f5 → const KeyType

F5 key.

f6 → const KeyType

F6 key.

f7 → const KeyType

F7 key.

f8 → const KeyType

F8 key.

f9 → const KeyType

F9 key.

f10 → const KeyType

F10 key.

f11 → const KeyType

F11 key.

f12 → const KeyType

F12 key.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KeyType>
A constant List of the values in this enum, in order of their declaration.