MouseEvent class

A mouse event.

Inheritance

Constructors

MouseEvent({required int x, required int y, required MouseButton button, required MouseEventType type, Set<Modifier> modifiers = const <Modifier>{}})
Creates a MouseEvent.
const

Properties

button MouseButton
Which button was pressed.
final
hashCode int
The hash code for this object.
no setteroverride
key String
The key string representation.
no setterinherited
modifiers Set<Modifier>
Active modifiers.
final
pressed bool
Whether a button is actively pressed or dragging.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type MouseEventType
The type of mouse event.
final
x int
X coordinate (1-indexed terminal coordinate).
final
y int
Y coordinate (1-indexed terminal coordinate).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override