InputParser class

A reactive input parser that converts byte streams from stdin into high-level InputEvents. It handles standard ASCII, CSI escape sequences (including Alt shortcuts, arrow keys, functional keys), SGR/X10 mouse protocols, bracketed paste, and focus events.

Constructors

InputParser({bool isWindows = false})
Creates a new InputParser.

Properties

hashCode int
The hash code for this object.
no setterinherited
isWindows bool
Indicates if the parser is running in a Windows environment.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(List<int> chunk) List<InputEvent>
Parses a chunk of bytes and returns all decoded InputEvents.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited