Terminal class abstract

Interface for the underlying native terminal.

Implementers

Constructors

Terminal()
Creates a new terminal instance suitable for the current platform.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disableRawMode() → void
Disables raw mode and restores the terminal’s original attributes.
enableRawMode() → void
Enables raw mode which allows us to process each keypress as it comes in. https://viewsourcecode.org/snaptoken/kilo/02.enteringRawMode.html
getScreenBufferSize() Point<int>
Returns the current size of the terminal screen buffer as a Point, where x is the number of columns and y is the number of rows.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited