Terminal constructor
Terminal()
Creates a new terminal instance suitable for the current platform.
Implementation
factory Terminal() => Platform.isWindows ? WindowsTerminal() : UnixTerminal();
Creates a new terminal instance suitable for the current platform.
factory Terminal() => Platform.isWindows ? WindowsTerminal() : UnixTerminal();