getScreenBufferSize abstract method

Point<int> getScreenBufferSize()

Returns the current size of the terminal screen buffer as a Point, where x is the number of columns and y is the number of rows.

Implementation

Point<int> getScreenBufferSize();