ControlSequence class

Represents a parsed ANSI control sequence from the terminal input.

Constructors

ControlSequence(int command, List<int> values)
Creates a new control sequence with the given command and values.

Properties

command int
The command character code.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<int>
The parameter values associated with this sequence.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited