MousePointer enum

Represents the mouse pointer shapes supported by compatible terminals via OSC 22.

Inheritance
Available extensions

Values

defaultCursor → const MousePointer

The platform default cursor (usually an arrow).

const MousePointer('default')
text → const MousePointer

Text selection cursor (I-beam).

const MousePointer('text')
pointer → const MousePointer

Hand/pointing cursor (indicates a link or clickable element).

const MousePointer('pointer')
crosshair → const MousePointer

Crosshair cursor (precision selection).

const MousePointer('crosshair')
help → const MousePointer

Help cursor (arrow with question mark).

const MousePointer('help')
progress → const MousePointer

Busy cursor with background activity indicator.

const MousePointer('progress')
wait → const MousePointer

Busy/loading cursor (hourglass or spinner).

const MousePointer('wait')
move → const MousePointer

Move/drag cursor (four-directional arrows).

const MousePointer('move')
notAllowed → const MousePointer

Prohibited action cursor (circle with slash).

const MousePointer('not-allowed')
grab → const MousePointer

Open hand cursor (before grabbing).

const MousePointer('grab')
grabbing → const MousePointer

Closed hand cursor (while dragging).

const MousePointer('grabbing')
none → const MousePointer

Invisible cursor.

const MousePointer('none')
alias → const MousePointer

Alias/shortcut cursor (arrow with link badge).

const MousePointer('alias')
copy → const MousePointer

Copy cursor (arrow with a plus sign).

const MousePointer('copy')
cell → const MousePointer

Cell selection cursor (thick crosshair).

const MousePointer('cell')
noDrop → const MousePointer

Item not allowed to be dropped here (circle with a diagonal slash).

const MousePointer('no-drop')
zoomIn → const MousePointer

Zoom-in cursor (magnifying glass with plus).

const MousePointer('zoom-in')
zoomOut → const MousePointer

Zoom-out cursor (magnifying glass with minus).

const MousePointer('zoom-out')
resizeUpDown → const MousePointer

Vertical resize cursor (two-headed vertical arrow).

const MousePointer('ns-resize')
resizeLeftRight → const MousePointer

Horizontal resize cursor (two-headed horizontal arrow).

const MousePointer('ew-resize')
allScroll → const MousePointer

All-scroll cursor (four-way arrow indicator).

const MousePointer('all-scroll')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The parameter value for the OSC 22 sequence.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MousePointer>
A constant List of the values in this enum, in order of their declaration.