exitAlternateScreen method
void
exitAlternateScreen()
Sends the sequence to exit the alternate screen buffer.
Implementation
void exitAlternateScreen() => backend.write(exitAlternateScreenSequence);
Sends the sequence to exit the alternate screen buffer.
void exitAlternateScreen() => backend.write(exitAlternateScreenSequence);