setMousePointer method

void setMousePointer(
  1. MousePointer pointer
)

Sets the mouse pointer shape to the specified pointer type.

Note: This uses the OSC 22 escape sequence, which is supported by some modern terminal emulators (such as Kitty or xterm), but is ignored by others (such as iTerm2 or Windows Terminal).

Implementation

void setMousePointer(MousePointer pointer) {
  backend.write('\x1b]22;${pointer.value}\x1b\\');
}