TraceEvent class

Constructors

TraceEvent({required String name, required String phase, required String category, required int timestamp, required int tid, required Map<String, String> args})
TraceEvent.fromJson(Map<String, dynamic> json)
factory

Properties

args Map<String, String>
final
category String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
phase String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tid int
final
timestamp int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited