TraceLogger class

A unified logging interface for the trace viewer application. Provides consistent ISO-8601 formatted timestamps for all output.

Constructors

TraceLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

error(String tag, String message, [Object? error, StackTrace? stackTrace]) → void
Logs an error message tagged with the given tag. Optionally includes an error object and stackTrace.
info(String tag, String message) → void
Logs an informational message tagged with the given tag.