field property
The targeted field for this token (e.g., 'dur', 'name', 'widget'). If null, matches against name, category, and all metadata.
Implementation
final String? field;
The targeted field for this token (e.g., 'dur', 'name', 'widget'). If null, matches against name, category, and all metadata.
final String? field;