SearchOverlay class

Inheritance

Constructors

SearchOverlay({required List<TraceSpan> spans, required void onMatchSelected(TraceSpan span), required void onQueryChanged(String query), required VoidCallback onClose, String initialQuery = ''})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initialQuery String
final
key Key?
The optional key for this widget.
finalinherited
onClose VoidCallback
final
onMatchSelected → void Function(TraceSpan span)
final
onQueryChanged → void Function(String query)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spans List<TraceSpan>
final

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
inherited
createState() State<SearchOverlay>
Creates the mutable state for this widget at a given location in the tree.
override
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
inherited
getIntrinsicWidth(int height) int
Computes the intrinsic width of this widget under the given height constraint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited