createState method
Creates the mutable state for this widget at a given location in the tree.
Implementation
@override
State<SearchOverlay> createState() => SearchOverlayState();
Creates the mutable state for this widget at a given location in the tree.
@override
State<SearchOverlay> createState() => SearchOverlayState();