HitGrid class

An imperative canvas widget drawing the Main Isolate flame chart spans.

Constructors

HitGrid(int width, int height)

Properties

grid List<TraceSpan?>
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

getHit(int x, int y) TraceSpan?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHit(int x, int y, TraceSpan span) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited