TimelineCanvas class

Inheritance

Constructors

TimelineCanvas({Key? key, required List<TraceSpan> spans, required double offsetX, required int offsetY, required double zoomLevel, required int maxSpanDuration, void onHitGridUpdated(HitGrid)?, double? measureStartMs, double? measureEndMs, int? selectionStartUs, int? selectionEndUs, TraceSpan? animatedSpan, double? animationProgress})
const

Properties

animatedSpan → TraceSpan?
final
animationProgress → double?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
The optional key for this widget.
finalinherited
maxSpanDuration → int
final
measureEndMs → double?
final
measureStartMs → double?
final
offsetX → double
final
offsetY → int
final
onHitGridUpdated → void Function(HitGrid)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionEndUs → int?
final
selectionStartUs → int?
final
spans → List<TraceSpan>
final
zoomLevel → double
final

Methods

createElement() → Element
Creates an Element to manage this widget's location in the tree.
override
getIntrinsicHeight(int width) → int
Computes the intrinsic height of this widget under the given width constraint.
override
getIntrinsicWidth(int height) → int
Computes the intrinsic width of this widget under the given height constraint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

debugUseBoolArray ↔ bool
getter/setter pair