createState method
Creates the mutable state for this widget at a given location in the tree.
Implementation
@override
State<TraceViewerApp> createState() => _TraceViewerAppState();
Creates the mutable state for this widget at a given location in the tree.
@override
State<TraceViewerApp> createState() => _TraceViewerAppState();