AnimationStatus enum

The status of an animation transition.

Inheritance
Available extensions

Values

dismissed → const AnimationStatus

The animation is stopped at the beginning (progress 0.0) and not visible.

forward → const AnimationStatus

The animation is running from beginning to end.

reverse → const AnimationStatus

The animation is running from end to beginning.

completed → const AnimationStatus

The animation is stopped at the end (progress 1.0) but remains visible.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AnimationStatus>
A constant List of the values in this enum, in order of their declaration.