TuiAnimationConfig class

Global configuration for the TUI animation framework.

Constructors

TuiAnimationConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

vsyncInterval Duration
The global refresh rate fallback (vsync equivalent). Defaults to 60Hz (16.6ms intervals) in standard console environments. Can be tuned dynamically at runtime by the user/developer (e.g. 8ms for 120Hz).
getter/setter pair