SubpixelRippleWidget class

A declarative Widget that embeds and renders ripples managed by a SubpixelRippleManager.

This separates the View/Rendering concerns from the ViewModel state.

Inheritance

Constructors

SubpixelRippleWidget({required SubpixelRippleManager manager, Key? key})
Creates a SubpixelRippleWidget.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
The optional key for this widget.
finalinherited
manager → SubpixelRippleManager
The manager containing the ripple state.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → Element
Creates an Element to manage this widget's location in the tree.
override
getIntrinsicHeight(int width) → int
Computes the intrinsic height of this widget under the given width constraint.
inherited
getIntrinsicWidth(int height) → int
Computes the intrinsic width of this widget under the given height constraint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited