ui/buffer library

Classes

Buffer
A 2D grid of cell data stored in parallel flat lists.
Compositor
Composites multiple layered buffers onto a single target buffer.
LayeredBuffer
A buffer positioned in a 2D space with a Z-index for layering.

Functions

isWideCodePoint(int codePoint) bool
Checks if a single code point represents a wide character.
isWideGrapheme(String grapheme) bool
Returns true if the given grapheme cluster is a double-width (wide) character.