fill method
Fills the entire buffer with a copy of cell.
Implementation
void fill(Cell cell) {
for (var i = 0; i < cells.length; i++) {
final targetCell = cells[i];
targetCell.char = cell.char;
targetCell.style = cell.style;
}
}
Fills the entire buffer with a copy of cell.
void fill(Cell cell) {
for (var i = 0; i < cells.length; i++) {
final targetCell = cells[i];
targetCell.char = cell.char;
targetCell.style = cell.style;
}
}