popClip method
void
popClip()
Pops the most recently pushed clip rectangle from the stack.
Implementation
void popClip() {
if (_clipStack.isNotEmpty) {
_clipStack.removeLast();
}
}
Pops the most recently pushed clip rectangle from the stack.
void popClip() {
if (_clipStack.isNotEmpty) {
_clipStack.removeLast();
}
}