pushClip method
Pushes a new clip rectangle onto the stack, intersecting it with the current active clip.
Implementation
void pushClip(Rect clipRect) {
_clipStack.add(activeClip.intersect(clipRect));
}
Pushes a new clip rectangle onto the stack, intersecting it with the current active clip.
void pushClip(Rect clipRect) {
_clipStack.add(activeClip.intersect(clipRect));
}