Cell.blank constructor
Cell.blank()
Creates a cell initialized as a solid space with empty style.
Implementation
Cell.blank() : char = ' ', style = Style.empty;
Creates a cell initialized as a solid space with empty style.
Cell.blank() : char = ' ', style = Style.empty;