isTransparent property
bool
get
isTransparent
Returns true if this cell has the transparent modifier active.
Implementation
bool get isTransparent => Modifier.has(style.modifiers, Modifier.transparent);
Returns true if this cell has the transparent modifier active.
bool get isTransparent => Modifier.has(style.modifiers, Modifier.transparent);