LayeredBuffer class

A buffer positioned in a 2D space with a Z-index for layering.

Constructors

LayeredBuffer({required Buffer buffer, required int x, required int y, int zIndex = 0})
Creates a layered buffer positioned at x, y with an optional zIndex.

Properties

buffer Buffer
The underlying buffer content for this layer.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int
The x coordinate offset of this layer.
final
y int
The y coordinate offset of this layer.
final
zIndex int
The z-index used for occlusion ordering (higher is on top).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited