CharmColors class abstract

The official CharmTone color palette from the Charm/Bubble Tea ecosystem.

Constructors

CharmColors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

additions → const List<Color>
The additions collection of colors from the CharmTone palette.
anchovy → const Color
The anchovy color from the CharmTone palette.
bbq → const Color
The bbq color from the CharmTone palette.
bengal → const Color
The bengal color from the CharmTone palette.
blush → const Color
The blush color from the CharmTone palette.
bok → const Color
The bok color from the CharmTone palette.
butter → const Color
The butter color from the CharmTone palette.
char → const Color
The char color from the CharmTone palette.
charple → const Color
The charple color from the CharmTone palette.
charpleRamp → const List<Color>
The charpleRamp collection of colors from the CharmTone palette.
cheeky → const Color
The cheeky color from the CharmTone palette.
cherry → const Color
The cherry color from the CharmTone palette.
chili → const Color
The chili color from the CharmTone palette.
citron → const Color
The citron color from the CharmTone palette.
coral → const Color
The coral color from the CharmTone palette.
cumin → const Color
The cumin color from the CharmTone palette.
damson → const Color
The damson color from the CharmTone palette.
darple → const Color
The darple color from the CharmTone palette.
deletions → const List<Color>
The deletions collection of colors from the CharmTone palette.
dolly → const Color
The dolly color from the CharmTone palette.
flamingo → const Color
The flamingo color from the CharmTone palette.
gator → const Color
The gator color from the CharmTone palette.
grape → const Color
The grape color from the CharmTone palette.
guac → const Color
The guac color from the CharmTone palette.
guppy → const Color
The guppy color from the CharmTone palette.
hazy → const Color
The hazy color from the CharmTone palette.
ice → const Color
The ice color from the CharmTone palette.
iron → const Color
The iron color from the CharmTone palette.
jelly → const Color
The jelly color from the CharmTone palette.
julep → const Color
The julep color from the CharmTone palette.
larple → const Color
The larple color from the CharmTone palette.
lichen → const Color
The lichen color from the CharmTone palette.
lilac → const Color
The lilac color from the CharmTone palette.
macaron → const Color
The macaron color from the CharmTone palette.
main → const List<Color>
The main collection of colors from the CharmTone palette.
malibu → const Color
The malibu color from the CharmTone palette.
mauve → const Color
The mauve color from the CharmTone palette.
mochi → const Color
The mochi color from the CharmTone palette.
mustard → const Color
The mustard color from the CharmTone palette.
neutrals → const List<Color>
The neutrals collection of colors from the CharmTone palette.
oceania → const Color
The oceania color from the CharmTone palette.
orchid → const Color
The orchid color from the CharmTone palette.
ox → const Color
The ox color from the CharmTone palette.
oyster → const Color
The oyster color from the CharmTone palette.
paprika → const Color
The paprika color from the CharmTone palette.
pepper → const Color
The pepper color from the CharmTone palette.
pickle → const Color
The pickle color from the CharmTone palette.
plum → const Color
The plum color from the CharmTone palette.
pom → const Color
The pom color from the CharmTone palette.
pony → const Color
The pony color from the CharmTone palette.
primary → const List<Color>
The primary collection of colors from the CharmTone palette.
prince → const Color
The prince color from the CharmTone palette.
salmon → const Color
The salmon color from the CharmTone palette.
salt → const Color
The salt color from the CharmTone palette.
sapphire → const Color
The sapphire color from the CharmTone palette.
sardine → const Color
The sardine color from the CharmTone palette.
sash → const Color
The sash color from the CharmTone palette.
smoke → const Color
The smoke color from the CharmTone palette.
soda → const Color
The soda color from the CharmTone palette.
spinach → const Color
The spinach color from the CharmTone palette.
squid → const Color
The squid color from the CharmTone palette.
sriracha → const Color
The sriracha color from the CharmTone palette.
steak → const Color
The steak color from the CharmTone palette.
steam → const Color
The steam color from the CharmTone palette.
steep → const Color
The steep color from the CharmTone palette.
tang → const Color
The tang color from the CharmTone palette.
thunder → const Color
The thunder color from the CharmTone palette.
toast → const Color
The toast color from the CharmTone palette.
tuna → const Color
The tuna color from the CharmTone palette.
turtle → const Color
The turtle color from the CharmTone palette.
uni → const Color
The uni color from the CharmTone palette.
urchin → const Color
The urchin color from the CharmTone palette.
violet → const Color
The violet color from the CharmTone palette.
warm → const List<Color>
The warm collection of colors from the CharmTone palette.
yam → const Color
The yam color from the CharmTone palette.
zest → const Color
The zest color from the CharmTone palette.
zinc → const Color
The zinc color from the CharmTone palette.