backgroundCode property
String
get
backgroundCode
Returns the ANSI escape sequence for setting this color as background.
Implementation
String get backgroundCode => '\x1b[48;2;$r;$g;${b}m';
Returns the ANSI escape sequence for setting this color as background.
String get backgroundCode => '\x1b[48;2;$r;$g;${b}m';