foregroundCode property
String
get
foregroundCode
Returns the ANSI escape sequence for setting this color as foreground.
Implementation
String get foregroundCode => '\x1b[38;2;$r;$g;${b}m';
Returns the ANSI escape sequence for setting this color as foreground.
String get foregroundCode => '\x1b[38;2;$r;$g;${b}m';