isTransparent property
bool
get
isTransparent
Returns true if this color is fully transparent (alpha == 0).
Implementation
bool get isTransparent => a == 0;
Returns true if this color is fully transparent (alpha == 0).
bool get isTransparent => a == 0;