Colors class abstract

Common standard colors.

Constructors

Colors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

black → const Color
The black color from the CharmTone palette.
blue → const Color
The blue color from the CharmTone palette.
green → const Color
The green color from the CharmTone palette.
orange → const Color
The orange color from the CharmTone palette.
red → const Color
The red color from the CharmTone palette.
white → const Color
The white color from the CharmTone palette.
yellow → const Color
The yellow color from the CharmTone palette.