BlendOption enum

Options for blending styles in effect helpers.

Inheritance
Available extensions

Values

replace → const BlendOption

Replace the target completely.

colorOnly → const BlendOption

Only replace the color, keep modifiers.

addModifiers → const BlendOption

Keep existing colors, only add new modifiers.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BlendOption>
A constant List of the values in this enum, in order of their declaration.