ColorMutator class

A mathematical mutator for 24-bit TrueColor cells.

Constructors

ColorMutator(double scalar)
Creates a ColorMutator with the given scalar.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scalar double
The scalar to multiply each RGB channel by.
final

Methods

dim(Color color) Color
Dims the given color by multiplying its RGB channels by scalar.
dimPacked(int argb) int
Dims the raw packed 32-bit integer color without allocating Color objects.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited