DimmerEffect class

Element for EffectWidget that absorbs pointer events. An effect that dims the colors beneath it.

Inheritance

Constructors

DimmerEffect({double scalar = 0.5})
Creates a dimmer effect.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scalar double
The scalar to dim colors by.
final

Methods

applyEffect(Buffer target, Rect bounds) → void
Applies the effect directly to the target buffer within bounds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited