EffectWidget class

A wrapper widget that applies a TerminalEffect to its descendants post-paint.

Inheritance

Constructors

EffectWidget({Key? key, required TerminalEffect effect, required Widget child, bool globalComposite = true})
Creates an effect widget.
const

Properties

child Widget
The child widget.
final
effect TerminalEffect
The effect to apply.
final
globalComposite bool
If true, the effect is applied globally during the Scene compositing phase. If false, the effect is applied locally to the widget's bounds immediately after paint.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
The optional key for this widget.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
override
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
override
getIntrinsicWidth(int height) int
Computes the intrinsic width of this widget under the given height constraint.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited