globalComposite property
If true, the effect is applied globally during the Scene compositing phase. If false, the effect is applied locally to the widget's bounds immediately after paint.
Implementation
final bool globalComposite;
If true, the effect is applied globally during the Scene compositing phase. If false, the effect is applied locally to the widget's bounds immediately after paint.
final bool globalComposite;