GlitchEffect class
An effect that glitches the runes horizontally.
- Inheritance
-
- Object
- TerminalEffect
- GlitchEffect
Constructors
- GlitchEffect(int randomOffset())
-
Creates a glitch effect.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- randomOffset → int Function()
-
A function that returns a random offset for each row.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyEffect(
Buffer target, Rect bounds) → void -
Applies the effect directly to the
targetbuffer withinbounds.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited