RegisteredEffect class

An effect registered with its layout bounds and stacking order.

Constructors

RegisteredEffect(TerminalEffect effect, Rect bounds, int zIndex, int originalIndex)
Creates a registered effect.

Properties

bounds Rect
The bounds to apply the effect within.
final
effect TerminalEffect
The effect to apply.
final
hashCode int
The hash code for this object.
no setterinherited
originalIndex int
The original layer index to ensure stable sorting.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zIndex int
The stacking order from the layer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited