TerminalEffect class abstract
A post-paint mutation applied to the composite terminal buffer.
- Implementers
Constructors
- TerminalEffect()
-
Creates a terminal effect.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyEffect(
Buffer target, Rect bounds) → void -
Applies the effect directly to the
targetbuffer withinbounds. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited