ui/event library

Classes

CursorPositionReportEvent
Event representing cursor position report.
Focusable
An interface that indicates a widget or state can receive keyboard focus.
FocusInEvent
Event fired when terminal receives focus.
FocusOutEvent
Event fired when terminal loses focus.
InputEvent
Base class for all input events.
KeyEvent
A keyboard event.
KeyEventHandler
An interface that indicates a widget or state can handle terminal keyboard events.
MouseEvent
A mouse event.
MouseEventHandler
An interface that indicates a widget or state can handle terminal mouse events.
MouseEventHandlerWithArea
An interface that indicates a widget or state can handle terminal mouse events with an explicit area boundary.
PasteEvent
A bracketed paste event.
TermKey
Constants for common key string representations (baseKey and logicalKey). These can be used in switch statements to pattern match on KeyEvent.baseKey or KeyEvent.logicalKey.

Enums

KeyType
Types of keys that can be pressed.
Modifier
Keyboard modifiers.
MouseButton
Mouse buttons.
MouseEventType
Mouse event type.