MouseEventHandler class abstract interface

An interface that indicates a widget or state can handle terminal mouse events.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleMouseEvent(MouseEvent event, int localX, int localY) → void
Handles a mouse event at local coordinates.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited