Interactive class abstract

Represents an interactive UI element.

Implementers

Constructors

Interactive()
Creates a new interactive element.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onActive() → void
Called when the element becomes active.
onEnter() → void
Called when the element is triggered (e.g., Enter key).
onInactive() → void
Called when the element becomes inactive.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited