MenuItem class

A specific item within a menu.

Inheritance

Constructors

Creates a new MenuItem.

Properties

hashCode int
The hash code for this object.
no setterinherited
item String
The label or text of the menu item.
getter/setter pair
position Point<int>
The local position of this menu item within the menu.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onActive() → void
Called when the element becomes active.
override
onEnter() → void
Called when the element is triggered (e.g., Enter key).
override
onInactive() → void
Called when the element becomes inactive.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited