BoxConstraints class

Immutable box layout constraints.

Constructors

BoxConstraints({int minWidth = 0, int maxWidth = 999999, int minHeight = 0, int maxHeight = 999999})
Creates box constraints with the given limits.
const
BoxConstraints.tightFor({int? width, int? height})
Creates box constraints that require the given width or height.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxHeight int
The maximum height allowed.
final
maxWidth int
The maximum width allowed.
final
minHeight int
The minimum height allowed.
final
minWidth int
The minimum width allowed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited