current property
BuildContext?
get
current
Accesses the active build context from the current Zone.
Implementation
static BuildContext? get current =>
Zone.current[#buildContext] as BuildContext?;
Accesses the active build context from the current Zone.
static BuildContext? get current =>
Zone.current[#buildContext] as BuildContext?;