Element class abstract
Instantiated element in the widget tree that keeps track of widget updates and state.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- parent ↔ Element?
-
The parent element in the widget tree.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget ↔ Widget
-
The widget that this element represents.
getter/setter pairoverride-getter
Methods
-
dependOnInheritedWidgetOfExactType<
T extends InheritedWidget> () → T? -
Obtains the nearest inherited widget of the given type
T.override -
mount(
Element? parent) → void -
Adds this element to the tree as a child of
parent. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
) → void - Rebuilds the element.
-
render(
Buffer buffer, Rect area) → void -
Renders the underlying widget to the provided
bufferwithin thearea. -
toString(
) → String -
A string representation of this object.
inherited
-
unmount(
) → void - Removes this element from the tree.
-
update(
Widget newWidget) → void - Updates this element to use a new Widget configuration.
-
visitChildren(
void visitor(Element child)) → void -
Invokes
visitoron each child element of this node.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited