visitChildren method
Invokes visitor on each child element of this node.
Implementation
void visitChildren(void Function(Element child) visitor) {}
Invokes visitor on each child element of this node.
void visitChildren(void Function(Element child) visitor) {}