FlexConstraint class

A proportional flexible space constraint.

Inheritance

Constructors

FlexConstraint(int flex)
Creates a constraint with the specified flex factor.
const

Properties

flex int
The flex factor to determine the proportional size.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited