updateShouldNotify abstract method
Whether the framework should notify widgets that inherit from this widget.
Implementation
bool updateShouldNotify(covariant InheritedWidget oldWidget);
Whether the framework should notify widgets that inherit from this widget.
bool updateShouldNotify(covariant InheritedWidget oldWidget);