LeafElement class
Default element for leaf widgets that do not build children.
Constructors
- LeafElement(Widget widget)
-
Creates a leaf element for the given
widget.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- parent ↔ Element?
-
The parent element in the widget tree.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget ↔ Widget
-
The widget that this element represents.
getter/setter pairinherited
Methods
-
dependOnInheritedWidgetOfExactType<
T extends InheritedWidget> () → T? -
Obtains the nearest inherited widget of the given type
T.inherited -
mount(
Element? parent) → void -
Adds this element to the tree as a child of
parent.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Buffer buffer, Rect area) → void -
Renders the underlying widget to the provided
bufferwithin thearea.override -
toString(
) → String -
A string representation of this object.
inherited
-
unmount(
) → void -
Removes this element from the tree.
inherited
-
update(
Widget newWidget) → void -
Updates this element to use a new Widget configuration.
inherited
-
visitChildren(
void visitor(Element child)) → void -
Invokes
visitoron each child element of this node.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited