MinMaxConstraint class

A constraint with min and max bounds.

Inheritance

Constructors

MinMaxConstraint({int min = 0, int max = 999999})
Creates a constraint with the specified min and max bounds.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
max int
The maximum size bound.
final
min int
The minimum size bound.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited