PercentageConstraint constructor
const
PercentageConstraint(
- int percentage
Creates a constraint based on a percentage of the parent size.
Implementation
const PercentageConstraint(this.percentage);
Creates a constraint based on a percentage of the parent size.
const PercentageConstraint(this.percentage);