setState method
Notifies the framework that the internal state of this object has changed.
Implementation
void setState(VoidCallback fn) {
fn();
(_context as StatefulElement).rebuild();
if (onNeedRepaint != null) {
onNeedRepaint!();
}
}
Notifies the framework that the internal state of this object has changed.
void setState(VoidCallback fn) {
fn();
(_context as StatefulElement).rebuild();
if (onNeedRepaint != null) {
onNeedRepaint!();
}
}