StatefulWidget class abstract

A widget that has mutable state.

Inheritance
Implementers

Constructors

StatefulWidget({Key? key})
Initializes a stateful widget.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
The optional key for this widget.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
override
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Buffer buffer, Rect area) → void
Renders the widget onto the provided buffer within the specified area.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited