render method
Renders the widget onto the provided buffer within the specified area.
Implementation
@override
void render(Buffer buffer, Rect area) {
// Lazily run stateful loop if rendered without app container.
final rootContext = StatefulElement(this)..mount(null);
rootContext.render(buffer, area);
}