StatelessElement class

An element that manages a StatelessWidget.

Inheritance

Constructors

StatelessElement(StatelessWidget widget)
Creates a stateless element to manage a StatelessWidget.

Properties

childElement Element?
The element corresponding to the built child widget.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
parent Element?
The parent element in the widget tree.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget Widget
The widget that this element represents.
getter/setter pairinherited

Methods

dependOnInheritedWidgetOfExactType<T extends InheritedWidget>() → T?
Obtains the nearest inherited widget of the given type T.
inherited
mount(Element? parent) → void
Adds this element to the tree and builds the child element.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild() → void
Rebuilds the child widget configuration and updates the child element.
override
render(Buffer buffer, Rect area) → void
Renders the underlying widget to the provided buffer within the area.
override
toString() String
A string representation of this object.
inherited
unmount() → void
Removes this element and its child from the tree.
override
update(Widget newWidget) → void
Updates this element to use a new Widget configuration.
override
visitChildren(void visitor(Element child)) → void
Invokes visitor on each child element of this node.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited