mount method

  1. @override
void mount(
  1. Element? parent
)
override

Adds this element to the tree and builds the child element.

Implementation

@override
/// Adds this element to the tree and builds the child element.
void mount(Element? parent) {
  super.mount(parent);
  rebuild();
}