unmount method

  1. @override
void unmount()
override

Removes this element and its child from the tree.

Implementation

@override
/// Removes this element and its child from the tree.
void unmount() {
  childElement?.unmount();
  super.unmount();
}