render method
Renders the widget onto the provided buffer within the specified area.
Implementation
@override
void render(Buffer buffer, Rect area) {
// Statelessly build and render child directly if called outside of an active element tree.
final rootContext = StatelessElement(this)..mount(null);
rootContext.render(buffer, area);
}