VoidCallback typedef
VoidCallback =
void Function()
Signature for callbacks that take no arguments and return no data.
Implementation
typedef VoidCallback = void Function();
Signature for callbacks that take no arguments and return no data.
typedef VoidCallback = void Function();