Modifier class abstract
Text modifiers represented as a bitmask for performance.
Constructors
- Modifier()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- blink → const int
- Blinking text modifier.
- bold → const int
- Bold text modifier.
- crossedOut → const int
- Crossed-out or strikethrough text modifier.
- dim → const int
- Dim or faint text modifier.
- Hidden text modifier.
- italic → const int
- Italic text modifier.
- none → const int
- No modifiers applied.
- reverse → const int
- Reversed foreground and background modifier.
- transparent → const int
- Transparency modifier for layer compositing.
- underline → const int
- Underlined text modifier.