Style class
A class representing style attributes for terminal output.
Constructors
Properties
- background → Color?
-
The background color of the cell.
final
- foreground → Color?
-
The foreground color of the text.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- modifiers → int
-
A bitmask of style modifiers applied to the cell.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
merge(
Style other) → Style - Merges another style onto this one.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- empty → const Style
- The default opaque style with no colors or modifiers.
- transparent → const Style
- A special transparent style.