debugPaintHoverEnabled top-level property
Global configuration flags for visual debugging in termui. Highlight the deepest leaf node under the mouse pointer.
Implementation
bool debugPaintHoverEnabled = false;
Global configuration flags for visual debugging in termui. Highlight the deepest leaf node under the mouse pointer.
bool debugPaintHoverEnabled = false;