debugShowTouchesEnabled top-level property
Show active touches and expansion rings for visual debugging.
Implementation
bool debugShowTouchesEnabled = false;
Show active touches and expansion rings for visual debugging.
bool debugShowTouchesEnabled = false;