kIsWeb top-level constant
bool
const kIsWeb
True if the current application is compiled to run on the web.
Implementation
const bool kIsWeb = identical(0, 0.0);
True if the current application is compiled to run on the web.
const bool kIsWeb = identical(0, 0.0);