ThemeData class

A class that holds the color and style configurations for a Theme.

Constructors

ThemeData({Style primaryStyle = Style.empty, Style backgroundStyle = Style.empty, Style textStyle = Style.empty, Style accentStyle = Style.empty, Style warningStyle = Style.empty, Style inputStyle = Style.empty, Style focusStyle = Style.empty, Style selectionStyle = Style.empty})
Creates a new ThemeData with the provided styles.
const

Properties

accentStyle Style
The style used to highlight secondary interactive elements.
final
backgroundStyle Style
The style used for application backgrounds.
final
focusStyle Style
The style applied to currently focused widgets.
final
hashCode int
The hash code for this object.
no setterinherited
inputStyle Style
The style used for text input areas.
final
primaryStyle Style
The style for primary branded UI elements.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionStyle Style
The style used for selected text or list items.
final
textStyle Style
The default style for standard text.
final
warningStyle Style
The style used for error or warning states.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

dark ThemeData
The default dark theme configuration.
final
light ThemeData
The default light theme configuration.
final