createState method
Creates the mutable state for this widget at a given location in the tree.
Implementation
@override
State<AnimatedButton> createState() {
final state = AnimatedButtonState();
_state = state;
return state;
}
Creates the mutable state for this widget at a given location in the tree.
@override
State<AnimatedButton> createState() {
final state = AnimatedButtonState();
_state = state;
return state;
}