onPressed property
void Function()
onPressed
final
Callback executed when the button is pressed and released.
Implementation
final void Function() onPressed;
Callback executed when the button is pressed and released.
final void Function() onPressed;