build method
Describes the part of the user interface represented by this widget.
Implementation
@override
Widget build(BuildContext context) {
widget._state = this;
return _AnimatedButtonRenderWidget(this);
}
Describes the part of the user interface represented by this widget.
@override
Widget build(BuildContext context) {
widget._state = this;
return _AnimatedButtonRenderWidget(this);
}