isHovered property
bool
get
isHovered
Whether the mouse cursor is currently hovering over the button bounds.
Implementation
bool get isHovered => _isHovered;
Whether the mouse cursor is currently hovering over the button bounds.
bool get isHovered => _isHovered;