isPressed property
bool
get
isPressed
Whether the button is currently in a pressed state.
Implementation
bool get isPressed => _isPressed;
Whether the button is currently in a pressed state.
bool get isPressed => _isPressed;