AbsorbPointer class

A widget that absorbs pointer events.

When absorbing is true, this widget prevents its subtree from receiving pointer events by terminating event routing at this level.

Inheritance

Constructors

AbsorbPointer({Key? key, required Widget child, bool absorbing = true})
Creates a widget that absorbs pointer events.
const

Properties

absorbing bool
Whether this widget absorbs pointer events.
final
child Widget
The widget below this widget in the tree.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
The optional key for this widget.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
override
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
override
getIntrinsicWidth(int height) int
Computes the intrinsic width of this widget under the given height constraint.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited