TermuiBinding class

A global registry of active termui engines (like SceneManager and PromptRunner) that should respond to hot reloads.

Constructors

TermuiBinding()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

reassembleAll() → void
Triggers a hot reload reassemble across all active scene managers and runners.
register(Reassemblable target) → void
Registers a Reassemblable target to receive hot reload events.
unregister(Reassemblable target) → void
Unregisters a Reassemblable target.