BuildOwner class

Undocumented public member.

Constructors

BuildOwner({void onNeedVisualUpdate()?})
Creates a new BuildOwner with an optional onNeedVisualUpdate callback.

Properties

hashCode int
The hash code for this object.
no setterinherited
isDirtyElements Set<Element>
Undocumented public member.
final
onNeedVisualUpdate → void Function()?
Callback triggered when a visual update (rebuild) is needed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildScope() → void
Rebuilds all dirty elements that have been scheduled.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scheduleBuildFor(Element element) → void
Schedules the given element to be rebuilt.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited