ui/widgets/core/element library

Classes

Element
Undocumented public member.
ElementWidgetElement
How children are aligned along the cross axis.
InheritedElement
A widget that propagates information down the tree.
LeafElement
Default element for leaf widgets that do not build children.
StatefulElement
A widget that has mutable state.
StatelessElement
A widget that has configuration but delegates rendering to its built child.

Extensions

HitTestExtension on Element
Extension providing recursive spatial hit testing down the mounted Element tree.