FocusableStateMixin<T extends StatefulWidget> mixin
A mixin that provides focus node management for interactive stateful widgets.
- Superclass constraints
- State<
T>
- State<
- Mixin applications
Properties
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- focusNode ↔ FocusNode
-
The underlying focus node.
getter/setter pair
- focusNodeIdPrefix → String
-
A unique ID prefix for the focus node.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalContext ↔ BuildContext?
-
Undocumented public member.
getter/setter pairinherited
- internalWidget ↔ T?
-
Undocumented public member.
getter/setter pairinherited
- isWidgetFocused → bool
-
Subclasses must override this to return the widget's focus property.
no setter
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → T
-
The current configuration.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant T oldWidget) → void -
Called whenever the widget configuration changes.
override
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called when the application is reassembled during debugging (hot reload).
inherited
-
setState(
VoidCallback fn) → void -
Notifies the framework that the internal state of this object has changed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateFocusIfNeeded(
bool wasFocused, bool isFocused) → void - Updates focus node request state if the widget focus changed.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited