Offset class

Represents an offset on the terminal cell grid coordinate space.

Constructors

Offset(int dx, int dy)
Creates an Offset with the given dx and dy.
const

Properties

dx int
The horizontal offset.
final
dy int
The vertical offset.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator +(Offset other) Offset
Adds other offset to this offset.
operator -(Offset other) Offset
Subtracts other offset from this offset.
operator ==(Object other) bool
The equality operator.
override

Constants

zero → const Offset
An offset with zero horizontal and vertical values.