Size class

Undocumented public member.

Constructors

Size(int width, int height)
Creates a Size with the given width and height.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
height int
The vertical dimension.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
The horizontal dimension.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

zero → const Size
A size with zero width and height.