ui/widgets/core/key library

Classes

GlobalKey<T extends State<StatefulWidget>>
A key that is unique across the entire element tree. Global keys allow widgets to be uniquely identified and retrieved from the registry.
Key
Undocumented public member.
ValueKey<T>
A concrete subclass of Key for matching widgets by a value.