ModalDismissBarrier class

A full-screen widget that blocks pointer events and invokes onDismiss when clicked.

Inheritance

Constructors

ModalDismissBarrier({Key? key, required Widget child, required void onDismiss()})
Creates a new ModalDismissBarrier.
const

Properties

child Widget
The child widget.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
The optional key for this widget.
finalinherited
onDismiss → void Function()
Callback when the barrier is clicked.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
override
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
inherited
getIntrinsicWidth(int height) int
Computes the intrinsic width of this widget under the given height constraint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited