ExecutionMode enum

Defines the execution mode for the PromptRunner.

Inheritance
Available extensions

Values

standalone → const ExecutionMode

The runner manages its own terminal event subscriptions, input handling, and terminal writing.

managed → const ExecutionMode

The runner is controlled by an external manager, bypassing hardware hooks and direct terminal writing.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ExecutionMode>
A constant List of the values in this enum, in order of their declaration.