hitTestable property
Whether this layer receives mouse events. If false, mouse events pass through to layers below.
Implementation
bool hitTestable;
Whether this layer receives mouse events. If false, mouse events pass through to layers below.
bool hitTestable;