clear method
Resets all cells in the buffer to transparent empty cells.
Implementation
@override
void clear() {
fillRect(
Rect(0, 0, bounds.width, bounds.height),
char: ' ',
modifiers: Modifier.transparent,
fg: 0,
bg: 0,
);
}
Resets all cells in the buffer to transparent empty cells.
@override
void clear() {
fillRect(
Rect(0, 0, bounds.width, bounds.height),
char: ' ',
modifiers: Modifier.transparent,
fg: 0,
bg: 0,
);
}