popClip method
Pops the most recently pushed clip rectangle from the stack.
Implementation
@override
void popClip() {
parent.popClip();
}
Pops the most recently pushed clip rectangle from the stack.
@override
void popClip() {
parent.popClip();
}