ui/widgets/core/widget library

Classes

ElementWidget
An element that manages an InheritedWidget.
InheritedWidget
An element that manages a StatefulWidget and its State.
State<T extends StatefulWidget>
The logic and internal state for a StatefulWidget.
StatefulWidget
An element that manages a StatelessWidget.
StatelessWidget
Instantiated element in the widget tree that keeps track of widget updates and state.
Widget
Undocumented public member.

Typedefs

VoidCallback = void Function()
Signature for callbacks that take no arguments and return no data.