ElementWidget class

An element that manages an InheritedWidget.

Inheritance

Constructors

ElementWidget(Widget child)
Creates an element widget bridging the tree.

Properties

child Widget
The child widget.
final
element Element?
The root element of the embedded tree.
no setter
hashCode int
The hash code for this object.
no setterinherited
internalElement Element?
Undocumented public member.
getter/setter pair
key Key?
The optional key for this widget.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
override
findState<S extends State<StatefulWidget>>() → S?
Finds a State of type S inside this widget's element tree.
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
inherited
getIntrinsicWidth(int height) int
Computes the intrinsic width of this widget under the given height constraint.
inherited
layout(BoxConstraints constraints, [BuildOwner? owner]) → void
Resolves the layout of the embedded widget tree.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Buffer buffer, Offset offset) → void
Paints the embedded widget tree.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited