State<T extends StatefulWidget> class abstract

The logic and internal state for a StatefulWidget.

Implementers

Constructors

State()

Properties

context BuildContext
The location in the tree where this widget builds.
no setter
hashCode int
The hash code for this object.
no setterinherited
internalContext BuildContext?
Undocumented public member.
getter/setter pair
internalWidget ↔ T?
Undocumented public member.
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget → T
The current configuration.
no setter

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
didChangeDependencies() → void
Called when a dependency of this State object changes.
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
dispose() → void
Called when this object is removed from the tree permanently.
initState() → void
Called when this object is inserted into the tree.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called when the application is reassembled during debugging (hot reload).
setState(VoidCallback fn) → void
Notifies the framework that the internal state of this object has changed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited