context property
BuildContext
get
context
The location in the tree where this widget builds.
Implementation
BuildContext get context => internalContext!;
The location in the tree where this widget builds.
BuildContext get context => internalContext!;