setState method
Notifies the framework that the internal state of this object has changed.
Implementation
void setState(VoidCallback fn) {
fn();
if (internalContext != null) {
(internalContext as Element).markNeedsBuild();
}
}
Notifies the framework that the internal state of this object has changed.
void setState(VoidCallback fn) {
fn();
if (internalContext != null) {
(internalContext as Element).markNeedsBuild();
}
}