StatelessWidget class abstract

Instantiated element in the widget tree that keeps track of widget updates and state.

Inheritance
Implementers

Constructors

StatelessWidget({Key? key})
Initializes a stateless widget.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
The optional key for this widget.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
createElement() Element
Creates an Element to manage this widget's location in the tree.
override
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
override
getIntrinsicWidth(int height) int
Computes the intrinsic width of this widget under the given height constraint.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited