Widget class abstract

Undocumented public member.

Implementers

Constructors

Widget({Key? key})
Initializes the widget configuration.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
The optional key for this widget.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
getIntrinsicWidth(int height) int
Computes the intrinsic width of this widget under the given height constraint.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

canUpdate(Widget oldWidget, Widget newWidget) bool
Whether the newWidget can be used to update an element that currently holds the oldWidget as its configuration.