GridCell class

A cell inside a Grid.

Constructors

GridCell(String char, [Style style = Style.empty])
Creates a GridCell.
const

Properties

char String
The character.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style
The style.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited