LazyList class

A virtual scrolling list widget. Only renders items within the visible viewport.

Inheritance

Constructors

LazyList({required int itemCount, required Widget itemBuilder(int index), int scrollOffset = 0})
Creates a LazyList.

Properties

hashCode → int
The hash code for this object.
no setterinherited
itemBuilder → Widget Function(int index)
Builder function to render a widget for the given index.
final
itemCount → int
Total number of items in the list.
final
key → Key?
The optional key for this widget.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollOffset ↔ int
The current scroll position index.
getter/setter pair

Methods

createElement() → Element
Creates an Element to manage this widget's location in the tree.
override
getIntrinsicHeight(int width) → int
Computes the intrinsic height of this widget under the given width constraint.
inherited
getIntrinsicWidth(int height) → int
Computes the intrinsic width of this widget under the given height constraint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited