dispose method
Called when this object is removed from the tree permanently.
Implementation
@override
void dispose() {
_parentRegistration?.children.remove(widget.focusNode);
widget.focusNode.parent = null;
super.dispose();
}
Called when this object is removed from the tree permanently.
@override
void dispose() {
_parentRegistration?.children.remove(widget.focusNode);
widget.focusNode.parent = null;
super.dispose();
}