hasError property
bool
get
hasError
Returns whether this field currently contains a validation error.
Implementation
bool get hasError => errorText != null;
Returns whether this field currently contains a validation error.
bool get hasError => errorText != null;