dispose method
Called when this object is removed from the tree permanently.
Implementation
@override
void dispose() {
Form.of(context)?.unregisterField(this);
if (widget._state == this) {
widget._state = null;
}
super.dispose();
}
Called when this object is removed from the tree permanently.
@override
void dispose() {
Form.of(context)?.unregisterField(this);
if (widget._state == this) {
widget._state = null;
}
super.dispose();
}