hasError property
bool
get
hasError
Returns whether this field currently holds an active validation error.
Implementation
bool get hasError => widget.errorText != null;
Returns whether this field currently holds an active validation error.
bool get hasError => widget.errorText != null;