fields property
Iterable<FormFieldState>
get
fields
Retrieves the list of currently registered form field states.
Implementation
Iterable<FormFieldState> get fields => _fields;
Retrieves the list of currently registered form field states.
Iterable<FormFieldState> get fields => _fields;