initState method
Called when this object is inserted into the tree.
Implementation
@override
void initState() {
super.initState();
widget._state = this;
}
Called when this object is inserted into the tree.
@override
void initState() {
super.initState();
widget._state = this;
}