SelectOption<T> class

An option in a selection form field.

Constructors

SelectOption(String label, T value)
Creates a SelectOption with a label and a value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
The label displayed for this option.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The underlying value of the option.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited