HorizontalRadioGroup class
A horizontal group of radio-like choices.
- Inheritance
-
- Object
- Widget
- StatefulWidget
- HorizontalRadioGroup
- Implemented types
Constructors
-
HorizontalRadioGroup({Key? key, required SelectionController<
String> controller, bool focused = false}) -
Creates a HorizontalRadioGroup.
const
Properties
-
controller
→ SelectionController<
String> -
The controller managing the selection state and options.
final
- focused → bool
-
Whether this group has active keyboard focus.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
The optional key for this widget.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → Element -
Creates an Element to manage this widget's location in the tree.
inherited
-
createState(
) → State< HorizontalRadioGroup> -
Creates the mutable state for this widget at a given location in the tree.
override
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Buffer buffer, Rect area) → void -
Renders the widget onto the provided
bufferwithin the specifiedarea.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited