createState method
Creates the mutable state for this widget at a given location in the tree.
Implementation
@override
State<HorizontalRadioGroup> createState() => HorizontalRadioGroupState();
Creates the mutable state for this widget at a given location in the tree.
@override
State<HorizontalRadioGroup> createState() => HorizontalRadioGroupState();