createState method
Creates the mutable state for this widget at a given location in the tree.
Implementation
@override
State<InkwellButton> createState() {
final state = InkwellButtonState();
_state = state;
return state;
}
Creates the mutable state for this widget at a given location in the tree.
@override
State<InkwellButton> createState() {
final state = InkwellButtonState();
_state = state;
return state;
}