handleMouseEvent method
Translates mouse interactions to update hover and pressed states.
Implementation
void handleMouseEvent(MouseEvent event, int localX, int localY) {
_state?.handleMouseEvent(event, localX, localY);
}
Translates mouse interactions to update hover and pressed states.
void handleMouseEvent(MouseEvent event, int localX, int localY) {
_state?.handleMouseEvent(event, localX, localY);
}