InkwellButtonState class

The state for an InkwellButton.

Inheritance
Mixed-in types

Constructors

InkwellButtonState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isHovered bool
Exposed for testing
no setter
isPressed bool
Exposed for testing
no setter
isTickerActive bool
Returns whether the periodic vsync ticker is currently running.
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
rippleCenterX double
Exposed for testing
no setter
rippleCenterY double
Exposed for testing
no setter
rippleProgress double
Exposed for testing
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vsyncInterval Duration
The vsync interval used by the widget fallback. Resolves dynamically to TuiAnimationConfig.vsyncInterval to support user-tuned frame rates.
no setterinherited
widget InkwellButton
The current configuration.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
deregisterEffect(TuiAnimationEffect effect) → void
Deregisters an animation effect.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
handleMouseEvent(MouseEvent event, int localX, int localY) → void
Handles mouse interactions.
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintEffects(Buffer buffer, Rect area, Style baseStyle) → void
Iterates and applies all active registered animation layers onto the buffer.
inherited
registerEffect(TuiAnimationEffect effect) → void
Registers an animation effect to be updated and rendered by this state.
inherited
setState(VoidCallback fn) → void
Notifies the framework that the internal state of this object has changed.
inherited
toString() String
A string representation of this object.
inherited
triggerEffect(TuiAnimationEffect effect, Point<int> clickPoint) → void
Triggers an effect at a specific local coordinate.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited