ui/widgets/interactive/drag_target library

Classes

DragTarget<T>
A wrapper widget that accepts dropped data from a Draggable.
DragTargetElement<T>
The element that manages the candidate list and lifecycle hooks for DragTarget.