builder property
The builder function that describes the widget content based on drag hover state.
Implementation
final Widget Function(
BuildContext context,
List<T> candidateData,
List<dynamic> rejectedData,
)
builder;
The builder function that describes the widget content based on drag hover state.
final Widget Function(
BuildContext context,
List<T> candidateData,
List<dynamic> rejectedData,
)
builder;