updateShouldNotify method
Whether the framework should notify widgets that inherit from this widget.
Implementation
@override
bool updateShouldNotify(FocusMarker oldWidget) =>
focusNode != oldWidget.focusNode;
Whether the framework should notify widgets that inherit from this widget.
@override
bool updateShouldNotify(FocusMarker oldWidget) =>
focusNode != oldWidget.focusNode;