FocusScopeState class

The state for a FocusScope widget.

Inheritance

Constructors

FocusScopeState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
focusNode FocusNode
The underlying FocusNode managed by this state.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
internalContext BuildContext?
Undocumented public member.
getter/setter pairinherited
internalWidget Focus?
Undocumented public member.
getter/setter pairinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget Focus
The current configuration.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createFocusNode() FocusNode
Factory method to construct the appropriate FocusNode instance.
override
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant Focus oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called when the application is reassembled during debugging (hot reload).
inherited
setState(VoidCallback fn) → void
Notifies the framework that the internal state of this object has changed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited