build method
Describes the part of the user interface represented by this widget.
Implementation
@override
Widget build(BuildContext context) {
return FocusMarker(focusNode: _focusNode, child: widget.child);
}
Describes the part of the user interface represented by this widget.
@override
Widget build(BuildContext context) {
return FocusMarker(focusNode: _focusNode, child: widget.child);
}