highlightForeground property
The foreground color when the button is focused or hovered. If null, the default foreground color is used.
Implementation
final Color? highlightForeground;
The foreground color when the button is focused or hovered. If null, the default foreground color is used.
final Color? highlightForeground;