ui/widgets/interactive/stream_builder library

Classes

AsyncSnapshot<T>
Immutable representation of the most recent interaction with an asynchronous computation.
StreamBuilder<T>
Widget that builds itself based on the latest snapshot of interaction with a Stream.

Enums

ConnectionState
The state of connection to an asynchronous computation.