StreamBuilder<T> class

Widget that builds itself based on the latest snapshot of interaction with a Stream.

Inheritance

Constructors

StreamBuilder({Key? key, Stream<T>? stream, T? initialData, required Widget builder(BuildContext context, AsyncSnapshot<T> snapshot)})
Creates a new StreamBuilder that builds itself based on the latest snapshot of interaction with the specified stream and whose build strategy is given by builder.
const

Properties

builder Widget Function(BuildContext context, AsyncSnapshot<T> snapshot)
The build strategy currently used by this builder.
final
hashCode int
The hash code for this object.
no setterinherited
initialData → T?
The data that will be used to create the initial snapshot.
final
key Key?
The optional key for this widget.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<T>?
The asynchronous computation to which this builder is currently connected.
final

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
inherited
createState() State<StreamBuilder<T>>
Creates the mutable state for this widget at a given location in the tree.
override
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
inherited
getIntrinsicWidth(int height) int
Computes the intrinsic width of this widget under the given height constraint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited