StreamBuilder<T> constructor

const StreamBuilder<T>({
  1. Key? key,
  2. Stream<T>? stream,
  3. T? initialData,
  4. required Widget builder(
    1. BuildContext context,
    2. AsyncSnapshot<T> snapshot
    ),
})

Creates a new StreamBuilder that builds itself based on the latest snapshot of interaction with the specified stream and whose build strategy is given by builder.

Implementation

const StreamBuilder({
  super.key,
  this.stream,
  this.initialData,
  required this.builder,
});