ui/widgets/interactive/tab_bar library

Classes

TabBar
A horizontal tab bar widget to select active views from a tab set.
TabBarElement
An element that manages the rendering and layout of a TabBar widget.
TabController
A controller that coordinates the active tab index across TabBar and TabPanel.
TabPanel
A container that renders only the widget of the active tab.
TabPanelElement
An element that manages the active panel rendering and layout of a TabPanel widget.