TabPanel class

A container that renders only the widget of the active tab.

Inheritance

Constructors

TabPanel({required TabController controller, required List<Widget> children, required List<FocusNode> tabFocusNodes})
Creates a TabPanel.

Properties

children List<Widget>
The list of widgets corresponding to each tab.
final
controller TabController
The controller that dictates which tab is active.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
The optional key for this widget.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabFocusNodes List<FocusNode>
The focus nodes corresponding to each tab.
final

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
override
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
inherited
getIntrinsicWidth(int height) int
Computes the intrinsic width of this widget under the given height constraint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited