ui/widgets/interactive_widgets library
Classes
- Button
- An interactive TUI button widget that triggers a callback when activated.
- Checkbox
- An interactive checkbox widget for toggling boolean flags.
-
Radio<
T> - An interactive radio button widget to select a single value from a group.
- Switch
- An interactive visual switch toggle widget representing true/false state.