ConstrainedBox class

Undocumented public member.

Inheritance

Constructors

ConstrainedBox({required BoxConstraints constraints, required Widget child})
Creates a widget that imposes additional constraints on its child.
const

Properties

child Widget
The child widget.
final
constraints BoxConstraints
The additional constraints to impose on the child.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
The optional key for this widget.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
override
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
override
getIntrinsicWidth(int height) int
Computes the intrinsic width of this widget under the given height constraint.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited