Clip enum

Different ways to clip a widget's content.

Inheritance
Available extensions

Values

none → const Clip

No clip at all. Content may overflow the widget's bounds.

hardEdge → const Clip

Clip the content to the widget's layout boundaries by dropping overflowing cells.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Clip>
A constant List of the values in this enum, in order of their declaration.