MainAxisAlignment enum
How children are aligned along the main axis.
Values
- start → const MainAxisAlignment
-
Place children as close to the start of the main axis as possible.
- end → const MainAxisAlignment
-
Place children as close to the end of the main axis as possible.
- center → const MainAxisAlignment
-
Place children as close to the center of the main axis as possible.
- spaceBetween → const MainAxisAlignment
-
Place free space evenly between children.
- spaceAround → const MainAxisAlignment
-
Place free space evenly between children, and half of that space before the first and after the last child.
- spaceEvenly → const MainAxisAlignment
-
Place free space evenly between children, and before the first and after the last child.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MainAxisAlignment> - A constant List of the values in this enum, in order of their declaration.