ui/widgets/layout/layout_builder library

Classes

LayoutBuilder
A widget that builds a subtree based on the incoming layout constraints.
LayoutBuilderElement
The element that manages the lifecycle of a LayoutBuilder.

Typedefs

LayoutWidgetBuilder = Widget Function(BuildContext context, BoxConstraints constraints)
Signature for the builder callback used by LayoutBuilder.