Positioned class

Undocumented public member.

Inheritance

Constructors

Positioned({int? left, int? top, int? right, int? bottom, int? width, int? height, required Widget child})
Creates a positioned widget to place a child inside a Stack.
const
Positioned.center({int? width, int? height, required Widget child})
Creates a centered positioned widget inside a Stack.
const

Properties

bottom int?
The distance from the bottom edge.
final
child Widget
The child widget.
final
hashCode int
The hash code for this object.
no setterinherited
height int?
The constrained height.
final
isCentered bool
Whether this positioned widget should be centered in the stack.
final
key Key?
The optional key for this widget.
finalinherited
left int?
The distance from the left edge.
final
The distance from the right edge.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top int?
The distance from the top edge.
final
width int?
The constrained width.
final

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
override
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
override
getIntrinsicWidth(int height) int
Computes the intrinsic width of this widget under the given height constraint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited