Row class
Undocumented public member.
Constructors
-
Row(List<
Widget> children, {Key? key, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, String? backgroundChar, Style? backgroundStyle}) -
Creates a horizontal layout for
children.const
Properties
- backgroundChar → String?
-
A background fill character.
final
- backgroundStyle → Style?
-
A background fill style.
final
-
children
→ List<
Widget> -
The children widgets to align horizontally.
final
- crossAxisAlignment → CrossAxisAlignment
-
How the children should be placed along the cross axis.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
The optional key for this widget.
finalinherited
- mainAxisAlignment → MainAxisAlignment
-
How the children should be placed along the main axis.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → Element -
Creates an Element to manage this widget's location in the tree.
override
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint.override -
getIntrinsicWidth(
int height) → int -
Computes the intrinsic width of this widget under the given
heightconstraint.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited