ui/widgets/layout/safe_layout library

Classes

SafeLayout
A layout widget that checks constraints and renders a fallback message (or custom fallback widget) if the terminal space is below the minimum required dimensions.
SafeLayoutElement
The element managing the lifecycle, constraints, and painting of SafeLayout.