fallback property
Optional custom fallback widget to display when constraints are violated. If not provided, defaults to a centered, red, bold "Screen too small!" text.
Implementation
final Widget? fallback;
Optional custom fallback widget to display when constraints are violated. If not provided, defaults to a centered, red, bold "Screen too small!" text.
final Widget? fallback;