ui/widgets/layout/split_pane library

Classes

SplitPane
A widget that divides a viewport into two side-by-side or stacked children.
SplitPaneElement
An element that manages the layout and rendering of a SplitPane widget.