render method
Renders the widget onto the provided buffer within the specified area.
Implementation
@override
void render(Buffer buffer, Rect area) {
// Fallback for direct widget rendering outside of active element tree
final rootContext = LeftBorderElement(this)..mount(null);
rootContext.render(buffer, area);
}