customOnKeyEvent property
An optional custom key event handler for unhandled events in the modal.
Implementation
final void Function(KeyEvent event)? customOnKeyEvent;
An optional custom key event handler for unhandled events in the modal.
final void Function(KeyEvent event)? customOnKeyEvent;