createState method
Creates the mutable state for this widget at a given location in the tree.
Implementation
@override
State<DropdownButton<T>> createState() => DropdownButtonState<T>();
Creates the mutable state for this widget at a given location in the tree.
@override
State<DropdownButton<T>> createState() => DropdownButtonState<T>();