createState method
Creates the mutable state for this widget at a given location in the tree.
Implementation
@override
OverlayState createState() => OverlayState();
Creates the mutable state for this widget at a given location in the tree.
@override
OverlayState createState() => OverlayState();