remove method
void
remove()
Removes this entry from the overlay it was inserted into.
Implementation
void remove() {
_overlayState?.remove(this);
_overlayState = null;
}
Removes this entry from the overlay it was inserted into.
void remove() {
_overlayState?.remove(this);
_overlayState = null;
}