onCanceled property
void Function()?
onCanceled
final
Callback triggered when the menu is dismissed without a selection.
Implementation
final void Function()? onCanceled;
Callback triggered when the menu is dismissed without a selection.
final void Function()? onCanceled;