KeyEventHandler class abstract interface

An interface that indicates a widget or state can handle terminal keyboard events.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleKeyEvent(KeyEvent event) bool
Handles a keyboard event, returning true if the event was consumed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited