PromptAbortedException class
Base exception thrown when a PromptRunner is aborted via PromptExitAction.abort.
- Implemented types
- Implementers
Constructors
- PromptAbortedException({required PromptExitTrigger trigger, KeyEvent? event, String message = 'Prompt runner aborted.'})
-
Creates a new PromptAbortedException.
const
Properties
- event → KeyEvent?
-
The raw key event that triggered the abort, if available.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Descriptive message explaining why the runner aborted.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trigger → PromptExitTrigger
-
The specific exit trigger that caused the abort.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited