PromptExitAction enum
Defines the state outcome of the PromptRunner when an exit trigger is matched.
Values
- complete → const PromptExitAction
-
Resolves the prompt runner's future with the current value retrieved from
onComplete. - cancel → const PromptExitAction
-
Resolves the prompt runner's future with
null, signaling cancellation without error. - abort → const PromptExitAction
-
Rejects the prompt runner's future by throwing a PromptAbortedException.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PromptExitAction> - A constant List of the values in this enum, in order of their declaration.