PromptExitTrigger enum
Defines keyboard inputs or signals that can terminate the prompt runner's execution.
Values
- enter → const PromptExitTrigger
-
Pressing the Enter key (carriage return
\r, newline\n, or key string'enter'). - escape → const PromptExitTrigger
-
Pressing the Escape key (key string
'escape'). - controlC → const PromptExitTrigger
-
Pressing Ctrl+C (character code 3).
- controlD → const PromptExitTrigger
-
Pressing Ctrl+D (character code 4, signifying EOF).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PromptExitTrigger> - A constant List of the values in this enum, in order of their declaration.