onComplete property
T Function()?
onComplete
final
An optional completion callback returning the final value of type T.
Implementation
final T Function()? onComplete;
An optional completion callback returning the final value of type T.
final T Function()? onComplete;