updateShouldNotify method
Whether the framework should notify widgets that inherit from this widget.
Implementation
@override
bool updateShouldNotify(PromptScope oldWidget) => false;
Whether the framework should notify widgets that inherit from this widget.
@override
bool updateShouldNotify(PromptScope oldWidget) => false;