ui/widgets/rich_text library
Classes
- RichText
- A widget that displays formatted text using a tree of TextSpan configurations.
- StyledChar
- A helper representing a single grapheme cluster with its style.
- StyledToken
- A helper representing a token (a word, spaces, or a newline) for wrapping.
- TextRun
- Represents a styled span of text.
- TextSpan
- An immutable span of text that can hold styling overrides and nested child spans.