StyledChar class

A helper representing a single grapheme cluster with its style.

Constructors

StyledChar(String char, Style style)
Creates a StyledChar mapping a grapheme string to its style.

Properties

char String
The isolated grapheme character.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style
The style bound to this character.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited