StyledToken class
A helper representing a token (a word, spaces, or a newline) for wrapping.
Constructors
-
StyledToken(List<
StyledChar> chars, {bool isWhitespace = false, bool isNewline = false}) - Instantiates a StyledToken representing a wrapped sequence of characters.
Properties
-
chars
→ List<
StyledChar> -
The styled characters representing this token.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNewline → bool
-
Indicates whether this token represents a newline.
final
- isWhitespace → bool
-
Indicates whether this token consists entirely of whitespace.
final
- length → int
-
Retrieves the character length of the token.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited