TextRun class

Represents a styled span of text.

Constructors

TextRun(String text, {Style style = Style.empty})
Creates a TextRun with an explicit text value and optional styling.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style
The style applied to the text.
final
text String
The string content of the text run.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override