SevenSegmentDisplay class

A widget that displays a multi-line segmented numerical readout.

Inheritance

Constructors

SevenSegmentDisplay({required String value, Color activeColor = Colors.green, Color inactiveColor = const Color(30, 30, 30)})
Creates a seven segment display.

Properties

activeColor Color
The color of the active segments.
final
hashCode int
The hash code for this object.
no setterinherited
inactiveColor Color
The color of the inactive segments.
final
key Key?
The optional key for this widget.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The value to display (can be numbers or some characters).
final

Methods

createElement() Element
Creates an Element to manage this widget's location in the tree.
inherited
getIntrinsicHeight(int width) int
Computes the intrinsic height of this widget under the given width constraint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Buffer buffer, Rect area) → void
Renders the widget onto the provided buffer within the specified area.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited