Animatable class abstract

An interface for widgets that support animation ticks or time-based rendering.

Implementers

Constructors

Animatable()

Properties

hashCode int
The hash code for this object.
no setterinherited
isAnimatable bool
Whether this object is currently animating.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited