TabController class

A controller that coordinates the active tab index across TabBar and TabPanel.

Constructors

TabController({required int length, int initialIndex = 0})
Creates a TabController with the given length and initialIndex.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
The currently active tab index.
getter/setter pair
length int
The total number of tabs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(void listener()) → void
Adds a listener to be notified when the active index changes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(void listener()) → void
Removes a previously added listener.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited