TextEditingValue class
Holds the configuration state of a TextField value.
Constructors
- TextEditingValue({String text = '', TextSelection selection = const TextSelection.collapsed(offset: 0)})
-
Creates a TextEditingValue.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
lines
→ List<
String> -
Text split into separate lines.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → TextSelection
-
The current text selection state.
final
- text → String
-
The text content.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override