ancestorIsLast property

List<bool> ancestorIsLast
final

A boolean list representing whether each ancestor of this node is the last child in its respective parent.

Implementation

final List<bool> ancestorIsLast;