TreeNode<T> class

A node in the hierarchical tree structure.

Constructors

TreeNode({required String label, required T value, List<TreeNode<T>> children = const [], bool isExpanded = false})
Creates a new TreeNode with the specified label and value.

Properties

children List<TreeNode<T>>
The child nodes nested under this node.
final
hashCode int
The hash code for this object.
no setterinherited
isExpanded bool
Whether this folder node is currently expanded to show its children.
getter/setter pair
isLeaf bool
Returns true if this node has no children.
no setter
label String
The label displayed for this node in the tree.
final
parent TreeNode<T>?
The parent node of this node, if any.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The underlying value associated with this node.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited