ui/window library

Classes

FocusManager
A node in the keyboard focus tree.
FocusNode
A representation of a node in the focus tree.
FocusScopeNode
A specialized focus scope node that manages focus traversal.
Window
A Window widget that acts as an isolated floating frame with borders, titles, and local content viewports.
WindowElement
Element class corresponding to Window, managing child reconciliation, layout and paint.