addWindow method
Adds a window to the manager and registers its focus node.
Implementation
void addWindow(Window window) {
windows.add(window);
rootFocusNode.addChild(window.focusNode);
}
Adds a window to the manager and registers its focus node.
void addWindow(Window window) {
windows.add(window);
rootFocusNode.addChild(window.focusNode);
}