removeWindow method
Removes a window from the manager and its focus node.
Implementation
void removeWindow(Window window) {
windows.remove(window);
window.focusNode.parent?.children.remove(window.focusNode);
}
Removes a window from the manager and its focus node.
void removeWindow(Window window) {
windows.remove(window);
window.focusNode.parent?.children.remove(window.focusNode);
}