BoolArray class

A memory-efficient boolean array backed by a 32-bit packed contiguous buffer.

Constructors

BoolArray(int length)
Creates a new BoolArray of the given length

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
The logical length of the array
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) bool
Gets the boolean value at the given index
operator []=(int index, bool value) → void
Sets the boolean value at the given index