IntervalNode<T extends num> class

Node in the AVL Interval Tree.

Constructors

IntervalNode(Interval<T> interval)
Creates a new IntervalNode wrapping the given interval.

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
The height of this node in the AVL tree.
getter/setter pair
interval Interval<T>
The underlying interval stored in this node.
final
left IntervalNode<T>?
The left child of this node.
getter/setter pair
maxEnd ↔ T
The maximum end value found in this node's subtree.
getter/setter pair
The right child of this node.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update() → void
Recalculates height and maxEnd of this node based on its children.

Operators

operator ==(Object other) bool
The equality operator.
inherited