operator [] method
The object at the given index in the list.
The index must be a valid index of this list,
which means that index must be non-negative and
less than length.
Implementation
@override
T operator [](int index) {
if (index < 0 || index >= length) {
throw RangeError.index(index, this);
}
return _buffer[(_head + index) % _capacity] as T;
}