operator []= method
Sets the value at the given index in the list to value.
The index must be a valid index of this list,
which means that index must be non-negative and
less than length.
Implementation
@override
void operator []=(int index, T value) {
if (index < 0 || index >= length) {
throw RangeError.index(index, this);
}
_buffer[(_head + index) % _capacity] = value;
}