Direction enum
Represents a 2D cardinal direction.
- Inheritance
- Implemented types
- Available extensions
Values
- up → const Direction
-
The upward direction.
const Direction(character: 'A') - down → const Direction
-
The downward direction.
const Direction(character: 'B') - left → const Direction
-
The leftward direction.
const Direction(character: 'D') - right → const Direction
-
The rightward direction.
const Direction(character: 'C')
Properties
- character → String
-
The ANSI control character representing this direction.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compareTo(
Direction other) → int -
Compares this object to another object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited