TraceCategory enum
Categories for surgical profiling of the framework's subsystems.
Values
- build → const TraceCategory
-
Traces related to building widgets.
- layout → const TraceCategory
-
Traces related to layout.
- paint → const TraceCategory
-
Traces related to painting/drawing.
- events → const TraceCategory
-
Traces related to user input events.
- compositor → const TraceCategory
-
Traces related to the compositor.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TraceCategory> - A constant List of the values in this enum, in order of their declaration.