IoTerminalBackend class

A terminal backend implementation using dart:io and FFI.

Implemented types

Constructors

IoTerminalBackend()
Creates a new IO terminal backend.

Properties

hashCode int
The hash code for this object.
no setterinherited
isWindows bool
Whether the host platform is Windows.
no setteroverride
rawInput Stream<List<int>>
Stream of raw input bytes from the terminal.
no setteroverride
rawTerminal Terminal
The low-level raw terminal instance.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Point<int>
Retrieves the current terminal size.
no setteroverride

Methods

disableRawMode() → void
Restores terminal configuration.
override
dispose() → void
Cleans up resources.
override
enableRawMode() → void
Configures raw mode.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
watchSize() Stream<Point<int>>
Watches terminal size changes.
override
write(String data) → void
Writes output data back to the terminal.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited