CursorPositionReportEvent class
Event representing cursor position report.
- Inheritance
-
- Object
- InputEvent
- CursorPositionReportEvent
Constructors
- CursorPositionReportEvent(int x, int y)
-
Creates a CursorPositionReportEvent.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- key → String
-
The key string representation.
no setterinherited
-
modifiers
→ Set<
Modifier> -
Active modifiers.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x → int
-
X coordinate.
final
- y → int
-
Y coordinate.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override