KeyEvent class
A keyboard event.
- Inheritance
-
- Object
- InputEvent
- KeyEvent
Constructors
Properties
- baseKey → String
-
Returns a normalized key string (e.g., 'Enter', 'Escape', 'S', 'Tab')
stripping out all modifiers.
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- key → String
-
The key string representation.
final
- logicalKey → String
-
Returns a human-readable string combining modifiers and the key,
e.g. "Control+W", "Alt+Shift+Enter", "A".
no setter
-
modifiers
→ Set<
Modifier> -
Active modifiers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → KeyType
-
The type of key.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override