KeyEvent class

A keyboard event.

Inheritance

Constructors

KeyEvent(String key, KeyType type, {Set<Modifier> modifiers = const <Modifier>{}})
Creates a KeyEvent.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
key String
The key string representation.
final
modifiers Set<Modifier>
Active modifiers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type KeyType
The type of key.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override