PasteEvent class
A bracketed paste event.
- Inheritance
-
- Object
- InputEvent
- PasteEvent
Constructors
- PasteEvent(String text)
-
Creates a PasteEvent.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- key → String
-
The key string representation.
no setteroverride
-
modifiers
→ Set<
Modifier> -
Active modifiers.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The pasted text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override