PathUtils class
Utility class for verifying whether paste input represents a potential file path.
Constructors
Properties
- fileSystem → FileSystem
-
The filesystem interface to query for path existence.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pathContext → Context
-
The path context providing platform-specific path structures (Windows/Unix).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isLexicallyPotentialFilePath(
String text) → bool -
Lexically detects if a pasted
textstring represents a potential local file path. -
isPotentialFilePath(
String text) → bool -
Detects if a pasted
textstring represents a potential local file path. -
isPotentialFilePathAsync(
String text) → Future< bool> -
Asynchronously detects if a pasted
textstring represents a potential local file path. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited