getScreenBufferSize method
Returns the current size of the terminal screen buffer as a Point,
where x is the number of columns and y is the number of rows.
Implementation
@override
Point<int> getScreenBufferSize() {
try {
if (stdout.hasTerminal) {
return Point(stdout.terminalColumns, stdout.terminalLines);
}
if (stderr.hasTerminal) {
return Point(stderr.terminalColumns, stderr.terminalLines);
}
} catch (_) {
// Ignore
}
return const Point(-1, -1);
}