terminal/terminal library

Classes

ControlSequence
Represents a parsed ANSI control sequence from the terminal input.
CursorPositionReportEvent
Event representing cursor position report.
FocusInEvent
Event fired when terminal receives focus.
FocusOutEvent
Event fired when terminal loses focus.
InputEvent
Base class for all input events.
KeyEvent
A keyboard event.
MouseEvent
A mouse event.
PasteEvent
A bracketed paste event.
Terminal
The main entry point for interacting with the terminal backend.

Enums

KeyType
Types of keys that can be pressed.
Modifier
Keyboard modifiers.
MouseButton
Mouse buttons.
MouseEventType
Mouse event type.
MousePointer
Represents the mouse pointer shapes supported by compatible terminals via OSC 22.