TraceSpan class
Interval representing a matched Begin/End trace event.
Constructors
Properties
-
args
→ Map<
String, String> -
final
- category → String
-
final
- depth → int
-
final
- displayLabel → String
-
final
- endUs → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startUs → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited