SearchOverlayState class
- Inheritance
-
- Object
- State<
SearchOverlay> - SearchOverlayState
Constructors
Properties
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
-
filteredSpans
↔ List<
TraceSpan> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalContext ↔ BuildContext?
-
Undocumented public member.
getter/setter pairinherited
- internalWidget ↔ SearchOverlay?
-
Undocumented public member.
getter/setter pairinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchController ↔ TextEditingController
-
getter/setter pair
- selectedIndex ↔ int
-
getter/setter pair
- widget → SearchOverlay
-
The current configuration.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant SearchOverlay oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called when the application is reassembled during debugging (hot reload).
inherited
-
setState(
VoidCallback fn) → void -
Notifies the framework that the internal state of this object has changed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited