TraceViewerApp class
- Inheritance
-
- Object
- Widget
- StatefulWidget
- TraceViewerApp
Constructors
Properties
- filePath → String?
-
final
- fileSystem → FileSystem
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
The optional key for this widget.
finalinherited
- maxTs → int?
-
final
- minTs → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spans
→ List<
TraceSpan> ? -
final
Methods
-
createElement(
) → Element -
Creates an Element to manage this widget's location in the tree.
inherited
-
createState(
) → State< TraceViewerApp> -
Creates the mutable state for this widget at a given location in the tree.
override
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint.inherited -
getIntrinsicWidth(
int height) → int -
Computes the intrinsic width of this widget under the given
heightconstraint.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited