SubpixelRipple class

Represents a single sub-pixel touch/drop ripple animation state.

Constructors

SubpixelRipple({required Point<int> center, required int startTime, required Color color, int durationMs = 500})
Creates a SubpixelRipple configuration.
const

Properties

center → Point<int>
Center coordinate of the ripple on the terminal grid.
final
color → Color
The primary color of the ripple.
final
durationMs → int
Duration of the ripple animation in milliseconds.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → int
Epoch millisecond timestamp when the ripple started.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited