ui/buffer library
Classes
- Buffer
- A 2D grid of Cells representing a draw buffer.
- Cell
- A single cell in the terminal buffer.
- Compositor
- Composites multiple layered buffers onto a single target buffer.
- LayeredBuffer
- A buffer positioned in a 2D space with a Z-index for layering.
Functions
-
isWideGrapheme(
String grapheme) → bool - Returns true if the given grapheme cluster is a double-width (wide) character.