Cell class
A single cell in the terminal buffer.
It only contains char and style, minimizing memory allocation overhead.
Constructors
- Cell(String char, Style style)
-
Creates a cell with the given
charandstyle. - Cell.blank()
- Creates a cell initialized as a solid space with empty style.
- Cell.empty()
- Creates a cell initialized as a transparent space.
Properties
- char ↔ String
-
The single grapheme cluster character for this cell.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- isTransparent → bool
-
Returns true if this cell has the transparent modifier active.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style ↔ Style
-
The style applied to this cell (includes transparency bit).
getter/setter pair
Methods
-
clone(
) → Cell - Clones the cell.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override