Compositor class
Composites multiple layered buffers onto a single target buffer.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
composite(
{required Buffer target, required List< LayeredBuffer> layers}) → void -
Flattens
layersontotargetin descending Z-index order (topmost first). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited