ui/color library

Classes

CharmColors
The official CharmTone color palette from the Charm/Bubble Tea ecosystem.
Color
Represents a 24-bit RGB color with 8-bit alpha, packed into a single 32-bit integer. Using a single final int field minimizes memory footprint for each Color instance.
Colors
Common standard colors.

Extensions

ColorIntExtension on int
Extension on int to provide easy access and manipulation of ARGB colors represented as 32-bit integers.