ColorIntExtension extension
Extension on int to provide easy access and manipulation of ARGB colors represented as 32-bit integers.
- on
Properties
- a → int
-
Available on int, provided by the ColorIntExtension extension
Extract the alpha channel (0-255).no setter - b → int
-
Available on int, provided by the ColorIntExtension extension
Extract the blue channel (0-255).no setter - g → int
-
Available on int, provided by the ColorIntExtension extension
Extract the green channel (0-255).no setter - isTransparent → bool
-
Available on int, provided by the ColorIntExtension extension
Returns true if this color is fully transparent (alpha == 0).no setter - r → int
-
Available on int, provided by the ColorIntExtension extension
Extract the red channel (0-255).no setter
Methods
-
withAlpha(
int a) → int -
Available on int, provided by the ColorIntExtension extension
Returns a new ARGB integer with the updated alpha value (0-255). -
withBlue(
int b) → int -
Available on int, provided by the ColorIntExtension extension
Returns a new ARGB integer with the updated blue value (0-255). -
withGreen(
int g) → int -
Available on int, provided by the ColorIntExtension extension
Returns a new ARGB integer with the updated green value (0-255). -
withRed(
int r) → int -
Available on int, provided by the ColorIntExtension extension
Returns a new ARGB integer with the updated red value (0-255).