EffectHelpers extension
Helper methods for TerminalEffect implementations.
- on
Methods
-
fillBackgroundStyle(
Rect bounds, Style style, BlendOption blend) → void -
Available on Buffer, provided by the EffectHelpers extension
Fills the background style of all cells inboundsusingblend. -
fillForegroundStyle(
Rect bounds, Style style, BlendOption blend) → void -
Available on Buffer, provided by the EffectHelpers extension
Fills the foreground style of all cells inboundsusingblend. -
rotateColumn(
Rect bounds, int colIndex, int amount) → void -
Available on Buffer, provided by the EffectHelpers extension
Rotates a specific column within the given bounds byamountdownward. -
rotateRow(
Rect bounds, int rowIndex, int amount) → void -
Available on Buffer, provided by the EffectHelpers extension
Rotates a specific row within the given bounds byamountrightward.