BuildContext class abstract
A handle to a location in the widget tree.
- Implementers
Constructors
Properties
Methods
-
dependOnInheritedWidgetOfExactType<
T extends InheritedWidget> () → T? -
Obtains the nearest inherited widget of the given type
T. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- current → BuildContext?
-
Accesses the active build context from the current Zone.
no setter