EdgeInsets class
An immutable set of offsets in each of the four cardinal directions in terminal space.
Constructors
- EdgeInsets.all(int value)
-
Creates insets where all edges have the same
value.const - EdgeInsets.fromLTRB(int left, int top, int right, int bottom)
-
Creates insets from specific
left,top,right, andbottomoffsets.const - EdgeInsets.only({int left = 0, int top = 0, int right = 0, int bottom = 0})
-
Creates insets with only the specified edges provided.
const
- EdgeInsets.symmetric({int vertical = 0, int horizontal = 0})
-
Creates insets with symmetrical
verticalandhorizontaloffsets.const
Properties
- bottom → int
-
The bottom edge offset.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- left → int
-
The left edge offset.
final
- right → int
-
The right edge offset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → int
-
The top edge offset.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- zero → const EdgeInsets
- An EdgeInsets with zero offsets for all edges.