PercentageConstraint class

A percentage-based layout constraint relative to parent size.

Inheritance

Constructors

PercentageConstraint(int percentage)
Creates a constraint based on a percentage of the parent size.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
percentage int
The percentage of the parent size (0 to 100).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited