Positioned class
Places a widget inside a Stack at specific coordinate offsets.
Constructors
Properties
- bottom → int?
-
The distance from the bottom edge.
final
- child → Widget
-
The child widget.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
The constrained height.
final
- key → Key?
-
The optional key for this widget.
finalinherited
- left → int?
-
The distance from the left edge.
final
- right → int?
-
The distance from the right edge.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → int?
-
The distance from the top edge.
final
- width → int?
-
The constrained width.
final
Methods
-
createElement(
) → Element -
Creates an Element to manage this widget's location in the tree.
override
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Buffer buffer, Rect area) → void -
Renders the widget onto the provided
bufferwithin the specifiedarea.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited