unmount method
Removes this element and its child from the tree.
Implementation
@override
/// Removes this element and its child from the tree.
void unmount() {
childElement?.unmount();
super.unmount();
}
Removes this element and its child from the tree.
@override
/// Removes this element and its child from the tree.
void unmount() {
childElement?.unmount();
super.unmount();
}