Widget class abstract
Abstract base class for all renderable widgets.
- Implementers
- Align
- Button
- Canvas
- Checkbox
- Column
- ConstrainedBox
- DecoratedBox
- ElementWidget
- Flexible
- Grid
- Help
- InheritedWidget
- LazyList
- LazyTable
- LeftBorder
- LinearProgressIndicator
- ListWidget
- NumberSelector
- Padding
- Paginator
- Positioned
- Radio
- RichText
- Row
- ScrollBar
- SevenSegmentDisplay
- SizedBox
- Slider
- Spinner
- SplitPane
- Stack
- StatefulWidget
- StatelessWidget
- Switch
- TabBar
- Table
- TabPanel
- Text
- TimerWidget
- TreeWidget
- Window
Properties
Methods
-
createElement(
) → Element - Creates an Element to manage this widget's location in the tree.
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Buffer buffer, Rect area) → void -
Renders the widget onto the provided
bufferwithin the specifiedarea. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited