reassembleAll static method
void
reassembleAll()
Triggers a hot reload reassemble across all active scene managers and runners.
Implementation
static void reassembleAll() {
// Convert to list to avoid concurrent modification during iteration
final targets = _activeTargets.toList();
for (final target in targets) {
target.reassemble();
}
}