DragSession class
Represents an active drag session.
Constructors
-
DragSession({required Object data, required Element sourceElement, required Point<
int> startMousePosition, required Point<int> currentMousePosition}) - Creates a DragSession instance.
Properties
-
currentMousePosition
↔ Point<
int> -
The current mouse position of the drag pointer.
getter/setter pair
- data → Object
-
The payload data being dragged.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceElement → Element
-
The element that initiated the drag.
final
-
startMousePosition
→ Point<
int> -
The initial mouse position when the drag started.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited