ui/widgets/core/geometry library
Classes
- Alignment
- A handle to a location in the widget tree.
- BoxConstraints
- Defines layout boundaries inside terminal cell limits.
- Constraint
- Abstract base class for all layout constraints.
- EdgeInsets
- An immutable set of offsets in each of the four cardinal directions in terminal space.
- FlexConstraint
- A proportional flexible space constraint.
- LengthConstraint
- A fixed length layout constraint.
- MinMaxConstraint
- A constraint with min and max bounds.
- Offset
- Represents an offset on the terminal cell grid coordinate space.
- PercentageConstraint
- A percentage-based layout constraint relative to parent size.
- Rect
- A 2D rectangle representing bounds in terminal space.
- Size
- Undocumented public member.