Offset class
Represents an offset on the terminal cell grid coordinate space.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator +(
Offset other) → Offset -
Adds
otheroffset to this offset. -
operator -(
Offset other) → Offset -
Subtracts
otheroffset from this offset. -
operator ==(
Object other) → bool -
The equality operator.
override