An interface representing a rendering system in a composited scene.
- Implemented types
- Implementers
Properties
- currentBuffer → Buffer?
-
The current rendering output buffer.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requestedCursorPosition
→ Point<
int> ? -
The requested cursor coordinates, if any.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showsCursor → bool
-
Whether the hardware terminal cursor should be shown.
no setterinherited
- wantsAlternateScreen → bool
-
Whether alternate screen buffer mode is requested.
no setterinherited
- wantsMouseTracking → bool
-
Whether mouse tracking features are requested.
no setterinherited
Methods
-
dispose(
) → void - Cleans up resources.
-
handleKeyEvent(
KeyEvent event) → bool - Handles key events routed to this renderer. Returns true if handled.
-
handleMouseEvent(
MouseEvent event) → bool - Handles mouse events routed to this renderer. Returns true if the event was consumed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resize(
int width, int height) → void - Resizes the renderer viewport and updates layout/buffers.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited