A contract defining terminal state requests from a runner or layer.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requestedCursorPosition
→ Point<
int> ? -
The requested cursor coordinates, if any.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showsCursor → bool
-
Whether the hardware terminal cursor should be shown.
no setter
- wantsAlternateScreen → bool
-
Whether alternate screen buffer mode is requested.
no setter
- wantsMouseTracking → bool
-
Whether mouse tracking features are requested.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited