attributes property
Single unified data array for fg, bg, and modifiers.
layout: fg, bg, mod, fg, bg, mod...
Implementation
@override
Uint32List get attributes => throw UnsupportedError(
'Flat attributes access not supported on Viewport',
);
Single unified data array for fg, bg, and modifiers.
layout: fg, bg, mod, fg, bg, mod...
Implementation
@override
set attributes(Uint32List val) => throw UnsupportedError(
'Flat attributes access not supported on Viewport',
);