InheritedWidget class abstract
An element that manages a StatefulWidget and its State.
- Inheritance
- Implementers
Constructors
- InheritedWidget({required Widget child})
-
Initializes an inherited widget with the given
child.const
Properties
Methods
-
createElement(
) → Element -
Creates an Element to manage this widget's location in the tree.
override
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint.override -
getIntrinsicWidth(
int height) → int -
Computes the intrinsic width of this widget under the given
heightconstraint.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
covariant InheritedWidget oldWidget) → bool - Whether the framework should notify widgets that inherit from this widget.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited