Widget class abstract
Undocumented public member.
- Implementers
- AbsorbPointer
- Align
- Canvas
- Column
- ConstrainedBox
- DecoratedBox
- Draggable
- DragTarget
- EffectWidget
- ElementWidget
- FittedBox
- Flexible
- Grid
- Help
- InheritedWidget
- LayoutBuilder
- LazyList
- LazyTable
- LeftBorder
- LinearProgressIndicator
- ListView
- ModalDismissBarrier
- NumberSelector
- Padding
- Paginator
- Positioned
- RichText
- Row
- SafeLayout
- ScrollBar
- SevenSegmentDisplay
- SizedBox
- Sparkline
- Spinner
- SplitPane
- Stack
- StatefulWidget
- StatelessWidget
- SubpixelRippleWidget
- TabBar
- Table
- TabPanel
- Text
- TimelineCanvas
- TimerWidget
- Window
Properties
Methods
-
createElement(
) → Element - Creates an Element to manage this widget's location in the tree.
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint. -
getIntrinsicWidth(
int height) → int -
Computes the intrinsic width of this widget under the given
heightconstraint. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited