ui/widgets/decorated_box library
Classes
- Border
- Represents the character set and style configuration used to draw a box border.
- BoxDecoration
- Defines the visual decoration style (background and borders) for a box.
- DecoratedBox
- A widget that paints a background decoration and border around a child widget.
- DecoratedBoxElement
- Element for DecoratedBox.