onlyDrawOnSpaces property
If true, the canvas will only paint its cells onto the target buffer where the target buffer cell currently contains a space (' ').
Implementation
final bool onlyDrawOnSpaces;
If true, the canvas will only paint its cells onto the target buffer where the target buffer cell currently contains a space (' ').
final bool onlyDrawOnSpaces;