ui/widgets/display/linear_progress_indicator library
Classes
- LinearProgressIndicator
- A progress bar widget that fills its horizontal area with block characters.
- LinearProgressIndicatorElement
- An element that manages the rendering of a LinearProgressIndicator widget.
Enums
- CrossAxisFill
- How to fill the cross axis for fractional steps.
- ProgressBarType
- The type of characters used to render the progress bar.
- ProgressDirection
- The direction the progress bar fills.
Typedefs
- GradientStop = ({Color color, double stop})
- A single color stop in a gradient.
-
ProgressColors
= ({List<
GradientStop> ? bg, List<GradientStop> ? fg}) - A set of foreground and background gradients.