Sparkline class
A sparkline widget for rendering high-density historical data.
Constructors
-
Sparkline(Iterable<
double> data, {double max = 1.0, ProgressDirection direction = ProgressDirection.leftToRight, ProgressBarType barType = ProgressBarType.braille, ProgressColors colorBuilder(int cellIndex, double v0, [double? v1, double? v2, double? v3])?, Style style = Style.empty}) -
Creates a Sparkline.
const
Properties
- barType → ProgressBarType
-
The type of characters used to render the graph (braille, quads, or blocks).
final
- colorBuilder → ProgressColors Function(int cellIndex, double v0, [double? v1, double? v2, double? v3])?
-
Optional dynamic coloring per cell.
final
-
data
→ Iterable<
double> -
The historical data points.
final
- direction → ProgressDirection
-
The direction time flows. In horizontal flow, bars grow vertically.
In vertical flow, bars grow horizontally.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
The optional key for this widget.
finalinherited
- max → double
-
The maximum value used to calculate bar fraction (0.0 to 1.0).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → Style
-
Fallback rendering style.
final
Methods
-
createElement(
) → Element -
Creates an Element to manage this widget's location in the tree.
override
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint.inherited -
getIntrinsicWidth(
int height) → int -
Computes the intrinsic width of this widget under the given
heightconstraint.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited