ui/widgets/display/spinner library
Classes
- Animatable
- An interface for widgets that support animation ticks or time-based rendering.
- Spinner
- A widget for displaying animated loading/waiting indicators in a TUI.
- SpinnerElement
- An element that manages the rendering and layout of a Spinner widget.