Radio<T> class
Undocumented public member.
- Inheritance
-
- Object
- Widget
- StatefulWidget
- Radio
- Implemented types
Constructors
Properties
- focused → bool
-
Whether the widget has keyboard focus.
final
- focusedStyle → Style
-
The rendering style applied when the radio button is focused.
final
- groupValue → T
-
The currently selected value of the radio group.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
The optional key for this widget.
finalinherited
- label → String
-
The descriptive label text next to the radio circle.
final
- onChanged → void Function(T newValue)
-
The callback triggered when this option is selected.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → Style
-
The normal rendering style.
final
- value → T
-
The specific value represented by this radio button.
final
Methods
-
createElement(
) → Element -
Creates an Element to manage this widget's location in the tree.
inherited
-
createState(
) → State< Radio< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint.inherited -
getIntrinsicWidth(
int height) → int -
Computes the intrinsic width of this widget under the given
heightconstraint.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited