RadioState<T> class
Undocumented public member.
- Inheritance
- Implemented types
- Mixed-in types
Constructors
Properties
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- focusNode ↔ FocusNode
-
The underlying focus node.
getter/setter pairinherited
- focusNodeIdPrefix → String
-
A unique ID prefix for the focus node.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalContext ↔ BuildContext?
-
Undocumented public member.
getter/setter pairinherited
-
internalWidget
↔ Radio<
T> ? -
Undocumented public member.
getter/setter pairinherited
- isSelected → bool
-
Whether this radio button is currently selected.
no setter
- isWidgetFocused → bool
-
Subclasses must override this to return the widget's focus property.
no setteroverride
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
widget
→ Radio<
T> -
The current configuration.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant Radio< T> oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
inherited
-
handleKeyEvent(
KeyEvent event) → bool -
Handles a keyboard event, returning true if the event was consumed.
override
-
handleMouseEvent(
MouseEvent event, int localX, int localY) → void -
Handles mouse events for the radio button.
override
-
initState(
) → void -
Called when this object is inserted into the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called when the application is reassembled during debugging (hot reload).
inherited
-
setState(
VoidCallback fn) → void -
Notifies the framework that the internal state of this object has changed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateFocusIfNeeded(
bool wasFocused, bool isFocused) → void -
Updates focus node request state if the widget focus changed.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited