SliderState class
The state for a Slider widget.
- Inheritance
- Implemented types
Constructors
Properties
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalContext ↔ BuildContext?
-
Undocumented public member.
getter/setter pairinherited
- internalWidget ↔ Slider?
-
Undocumented public member.
getter/setter pairinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → Slider
-
The current configuration.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant Slider oldWidget) → void -
Called whenever the widget configuration changes.
override
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
handleKeyEvent(
KeyEvent event) → bool -
Handles keyboard events for moving the slider.
override
-
handleMouseEvent(
MouseEvent event, int localX, int localY, Rect area) → void -
Handles mouse events to update the slider's value on drag or click.
override
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called when the application is reassembled during debugging (hot reload).
inherited
-
setState(
VoidCallback fn) → void -
Notifies the framework that the internal state of this object has changed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited