FileTreeHelper class

Helper class to construct TreeNodes from direct local file system path structures.

Constructors

FileTreeHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buildFromPath(FileSystem fs, String path, {bool expandRoot = true}) TreeNode<FileSystemEntity>
Recursively reads a file system path and returns a TreeNode<FileSystemEntity> hierarchy.