SizedBox class
Undocumented public member.
Constructors
- SizedBox({int? width, int? height, Widget? child})
-
Creates a sized box to enforce
widthandheight.const - SizedBox.expand({Widget? child})
-
Creates a sized box that expands to fit its parent.
const
- SizedBox.shrink({Widget? child})
-
Creates a sized box with 0 width and height.
const
Properties
- child → Widget?
-
The child widget.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
The constrained height.
final
- key → Key?
-
The optional key for this widget.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int?
-
The constrained width.
final
Methods
-
createElement(
) → Element -
Creates an Element to manage this widget's location in the tree.
override
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint.override -
getIntrinsicWidth(
int height) → int -
Computes the intrinsic width of this widget under the given
heightconstraint.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited