LazyList class
A virtual scrolling list widget. Only renders items within the visible viewport.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → Widget Function(int index)
-
Builder function to render a widget for the given index.
final
- itemCount → int
-
Total number of items in the list.
final
- key → Key?
-
The optional key for this widget.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollOffset ↔ int
-
The current scroll position index.
getter/setter pair
Methods
-
createElement(
) → Element -
Creates an Element to manage this widget's location in the tree.
inherited
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Buffer buffer, Rect area) → void -
Renders the widget onto the provided
bufferwithin the specifiedarea.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited