PopupMenuItem<T> class
An item in a popup menu.
Constructors
- PopupMenuItem({required T value, required Widget child, bool enabled = true})
-
Creates a new popup menu item with the given
valueandchild.const
Properties
- child → Widget
-
The widget displayed for this menu item.
final
- enabled → bool
-
Whether this item is enabled and selectable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The value associated with this menu item.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited