ui/widgets/prompt_runner library

Classes

PromptRunner<T>
A helper class to run an interactive terminal prompt inline. It encapsulates the event loop, rendering to an inline buffer, and lifecycle management.

Extensions

PrintWidgetExtension on Terminal
Extension on term.Terminal to print a widget inline using the double-buffered renderer layout.