PrintWidgetExtension extension

Extension on term.Terminal to print a widget inline using the double-buffered renderer layout.

on

Methods

printWidget(Widget widget) → void

Available on Terminal, provided by the PrintWidgetExtension extension

Renders and prints the given widget to standard output at the current inline cursor position.