StyledChar class
A helper representing a single grapheme cluster with its style.
Constructors
- StyledChar(String char, Style style)
- Creates a StyledChar mapping a grapheme string to its style.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited