StatefulBuilder class
A custom stateful builder widget matching standard Flutter patterns.
It allows stateful builders to declare their widget layouts dynamically
and obtain local access to setState to trigger rebuilds within inline loops.
- Inheritance
-
- Object
- Widget
- StatefulWidget
- StatefulBuilder
Constructors
- StatefulBuilder({required Widget builder(BuildContext context, void setState(void ()))})
-
Creates a StatefulBuilder.
const
Properties
- builder → Widget Function(BuildContext context, void setState(void ()))
-
The builder callback.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
The optional key for this widget.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → Element -
Creates an Element to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulBuilder> -
Creates the mutable state for this widget at a given location in the tree.
override
-
getIntrinsicHeight(
int width) → int -
Computes the intrinsic height of this widget under the given
widthconstraint.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Buffer buffer, Rect area) → void -
Renders the widget onto the provided
bufferwithin the specifiedarea.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited