ui/widgets/tab_bar library
Classes
- TabBar
- A horizontal tab bar widget to select active views from a tab set.
- TabController
- A controller that coordinates the active tab index across TabBar and TabPanel.
- TabPanel
- A container that renders only the widget of the active tab.