ui/widgets/text library
Classes
- Text
- A widget that renders styled text with optional wrapping.
Enums
- TextAlign
- Text alignments for TUI rendering.
Functions
-
measureStringWidth(
String text) → int - Measures the physical cell width of a string in a terminal, correctly accounting for CJK and Emoji characters that occupy 2 cells.