ui/widgets/text_field library
Classes
- TextEditingController
- A controller that notifies listeners when editing value changes.
- TextEditingValue
- Holds the configuration state of a TextField value.
- TextField
- An interactive single-line or multi-line text input field.
- TextFieldShortcut
- A keyboard shortcut representation for assigning to TextFieldActions.
- TextFieldState
- The state for a TextField.
- TextSelection
- Represents the visual cursor selection offset in terminal cells.
Enums
- TextFieldAction
- Actions supported by the TextField widget.