TextEditingController class

A controller that notifies listeners when editing value changes.

Constructors

TextEditingController({String? text})
Creates a TextEditingController.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Gets the current text string.
getter/setter pair
value TextEditingValue
Gets the current editing value.
getter/setter pair

Methods

addListener(void listener()) → void
Adds a listener.
clear() → void
Clears the text.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
redo() → void
Redoes the last undone change.
removeListener(void listener()) → void
Removes a listener.
saveStateToHistory() → void
Pushes current state to undo history.
toString() String
A string representation of this object.
inherited
undo() → void
Undoes the last change.

Operators

operator ==(Object other) bool
The equality operator.
inherited