TextFieldAction enum
Actions supported by the TextField widget.
Values
- moveLeft → const TextFieldAction
-
Move cursor left.
- moveRight → const TextFieldAction
-
Move cursor right.
- moveUp → const TextFieldAction
-
Move cursor up.
- moveDown → const TextFieldAction
-
Move cursor down.
- moveWordLeft → const TextFieldAction
-
Move cursor one word to the left.
- moveWordRight → const TextFieldAction
-
Move cursor one word to the right.
- moveToLineStart → const TextFieldAction
-
Move cursor to the start of the line.
- moveToLineEnd → const TextFieldAction
-
Move cursor to the end of the line.
- deleteLeft → const TextFieldAction
-
Delete character to the left.
- deleteRight → const TextFieldAction
-
Delete character to the right.
- deleteWordLeft → const TextFieldAction
-
Delete word to the left.
- deleteWordRight → const TextFieldAction
-
Delete word to the right.
- deleteToLineStart → const TextFieldAction
-
Delete to the start of the line.
- deleteToLineEnd → const TextFieldAction
-
Delete to the end of the line.
- undo → const TextFieldAction
-
Undo last change.
- redo → const TextFieldAction
-
Redo last undone change.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TextFieldAction> - A constant List of the values in this enum, in order of their declaration.