TextFieldShortcut class
A keyboard shortcut representation for assigning to TextFieldActions.
Constructors
-
TextFieldShortcut({KeyType? type, String? key, Set<
Modifier> modifiers = const <ev.Modifier>{}}) -
Creates a TextFieldShortcut.
const
Properties
Methods
-
matches(
KeyEvent event) → bool - Returns true if this shortcut matches the given KeyEvent.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override