TextSelection class
Represents the visual cursor selection offset in terminal cells.
Constructors
- TextSelection({required int baseOffset, required int extentOffset, int cursorLine = 0, int cursorColumn = 0})
-
Creates a TextSelection.
const
- TextSelection.collapsed({required int offset, int line = 0, int column = 0})
-
Creates a collapsed TextSelection at the given offset.
const
Properties
- baseOffset → int
-
Base offset.
final
- cursorColumn → int
-
Column index.
final
- cursorLine → int
-
Line index.
final
- extentOffset → int
-
Extent offset.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isCollapsed → bool
-
Whether the selection is collapsed.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override