FlatNode<T> class

Helper info for rendering a flattened tree node.

Constructors

FlatNode({required TreeNode<T> node, required int depth, required List<bool> ancestorIsLast})
Creates a FlatNode indicating the node's layout depth and ancestorIsLast info.

Properties

ancestorIsLast List<bool>
A boolean list representing whether each ancestor of this node is the last child in its respective parent.
final
depth int
The depth level of the node in the tree hierarchy.
final
hashCode int
The hash code for this object.
no setterinherited
node TreeNode<T>
The tree node being flattened.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited