IntervalTree<T extends num> class
An AVL-based self-balancing Interval Tree.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
root
↔ IntervalNode<
T> ? -
The root node of the tree.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
insert(
Interval< T> interval) → void - Inserts a single interval.
-
insertAll(
Iterable< Interval< intervals) → voidT> > - Inserts multiple intervals. Optimized for sorted intervals.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
T start, T end, void onOverlap(Interval< T> interval)) → void -
Queries all intervals that overlap with
start, end. Zero-allocation recursive search using callback. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited